@@ -4,7 +4,7 @@
 
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 Gerber van der Graaf
 
    This file is part of libgpiv.
 
@@ -31,7 +31,7 @@
 FILENAME:                gpiv.h
 
 
-LAST MODIFICATION DATE: $Id: gpiv.h,v 1.26 2008-04-09 06:10:27 gerber Exp $
+LAST MODIFICATION DATE: $Id: gpiv.h,v 1.27 2008-09-25 13:19:53 gerber Exp $
 */
 
 /*! \mainpage Documentation of Libgpiv API
@@ -212,6 +212,13 @@ gpiv_fwrite_* (gchar *filename, ...)
 #include <fcntl.h>
 #endif /* ENABLE_TRIG */
 
+#ifdef ENABLE_MPI
+#include <mpi/mpi.h>
+#endif /* ENABLE_MPI */
+
+#ifdef _OPENMP
+#include <omp.h>
+#endif
 
 /*
  * General macro definitions
