@@ -5,7 +5,7 @@
 
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 Gerber van der Graaf
 
    This file is part of libgpiv.
 
@@ -54,7 +54,7 @@ EXTERNAL FUNCTIONS:
 
 SOURCE:                  lib/img.c
 
-LAST MODIFICATION DATE:  $Id: gpiv-img.h,v 1.2 2008-04-09 06:10:27 gerber Exp $
+LAST MODIFICATION DATE:  $Id: gpiv-img.h,v 1.3 2008-09-25 13:19:53 gerber Exp $
  */
 
 #ifndef __LIBGPIV_IMG_H__
@@ -434,6 +434,16 @@ gpiv_img_fread_davis_parameters		(const gchar		*fname,
 					GpivImagePar		*image_par
 					);
 
+#ifdef ENABLE_MPI
+/**
+ *      Broadcasts only required parameters of GpivImagePar for MPI
+ *
+ *      @param[in] image_par   image parameters
+ */
+void
+gpiv_img_mpi_bcast_imgpar		(GpivImagePar		*image_par
+					);
 
+#endif /* ENABLE_MPI */
 #endif /* __LIBGPIV_IMG_H__ */
 
