@@ -3,8 +3,7 @@
 /*
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
-
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 Gerber van der Graaf
    This file is part of libgpiv.
 
    Libgpiv is free software; you can redistribute it and/or modify
@@ -72,7 +71,7 @@ EXTERNAL FUNCTIONS:      gpiv_io_make_fname
                          gpiv_fread_davis_image
                          gpiv_read_davis_image
 
-LAST MODIFICATION DATE:  $Id: gpiv-io.h,v 1.1 2007-11-23 16:12:18 gerber Exp $
+LAST MODIFICATION DATE:  $Id: gpiv-io.h,v 1.3 2008-05-07 08:24:44 gerber Exp $
  --------------------------------------------------------------- */
 
 /*!
@@ -82,7 +81,7 @@ LAST MODIFICATION DATE:  $Id: gpiv-io.h,v 1.1 2007-11-23 16:12:18 gerber Exp $
 SOURCES:                lib/io.c, lib/io_hdf.c  lib/io_image.c  lib/io_png.c  
                         lib/io_raw.c
 
-LAST MODIFICATION DATE:  $Id: gpiv-io.h,v 1.1 2007-11-23 16:12:18 gerber Exp $
+LAST MODIFICATION DATE:  $Id: gpiv-io.h,v 1.3 2008-05-07 08:24:44 gerber Exp $
 
  */
 /*---------------------------------------------------------------------------*/
@@ -110,8 +109,8 @@ LAST MODIFICATION DATE:  $Id: gpiv-io.h,v 1.1 2007-11-23 16:12:18 gerber Exp $
 #define GPIV_EXT_TA            ".ta"           /**< Extension of time averaged file name */
 #define GPIV_EXT_SUBSTR        ".substr"       /**< Extension of file name with substracted data */
 
-#define GPIV_EXT_GPIV          ".gpi"	       /**< Extension of gpiv file name (HDF 5 format) */
-#define GPIV_EXT_GPIV_UPCASE   ".GPI"          /**< Uppercase extension of gpiv file name (HDF 5 format) */
+#define GPIV_EXT_GPIV          ".h5"	       /**< Extension of gpiv file name (HDF 5 format) */
+#define GPIV_EXT_GPIV_UPCASE   ".H5"           /**< Uppercase extension of gpiv file name (HDF 5 format) */
 #define GPIV_EXT_PIV           ".piv"	       /**< Extension of piv file name (ASCII format) */
 #define GPIV_EXT_DAVIS         ".img"          /**< DaVis image format */
 #define GPIV_EXT_DAVIS_UPCASE  ".IMG"          /**< Uppercase DaVis image format */
@@ -145,7 +144,7 @@ to read properly the gpiv_image but may not
 enum GpivDataFormat { 
     GPIV_RR = 1, 
     GPIV_DAV = 2 
-} pdf;
+};
 
 
 
