@@ -3,7 +3,8 @@
 /*
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of libgpiv.
    Libgpiv is free software; you can redistribute it and/or modify
@@ -41,7 +42,10 @@ EXTERNAL FUNCTIONS:      gpiv_img_parameters_set
 			 gpiv_img_fwrite_hdf5_parameters
                          gpiv_img_fread_davis_parameters
 
-LAST MODIFICATION DATE:  $Id: img.c,v 1.19 2008-04-09 06:10:28 gerber Exp $
+                         gpiv_img_mpi_bcast_imgpar
+
+
+LAST MODIFICATION DATE:  $Id: img.c,v 1.21 2008-09-25 13:19:53 gerber Exp $
  --------------------------------------------------------------- */
 
 #include <stdio.h>
@@ -1401,43 +1405,43 @@ img_print_parameters (FILE *fp,
          */
         if (image_par->ncolumns__set) {
             if (key) {
-                printf ("%s.%s: %d\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %d\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__NCOLUMNS, 
                         image_par->ncolumns);
             } else {
-                printf ("%s: %d\n", GPIV_IMGPAR_KEY__NCOLUMNS, 
+                printf ("%s %d\n", GPIV_IMGPAR_KEY__NCOLUMNS, 
                         image_par->ncolumns);
             }
         }
 
         if (image_par->nrows__set) {
             if (key) {
-                printf ("%s.%s: %d\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %d\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__NROWS, 
                         image_par->nrows);
             } else {
-                printf ("%s: %d\n", GPIV_IMGPAR_KEY__NROWS, 
+                printf ("%s %d\n", GPIV_IMGPAR_KEY__NROWS, 
                         image_par->nrows);
             }
         }
 
         if (image_par->x_corr__set) {
             if (key) {
-                printf ("%s.%s: %d\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %d\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__X_CORR, 
                         image_par->x_corr);
             } else {
-                printf ("%s: %d\n", GPIV_IMGPAR_KEY__X_CORR, image_par->x_corr);
+                printf ("%s %d\n", GPIV_IMGPAR_KEY__X_CORR, image_par->x_corr);
             }
         }
 
         if (image_par->depth__set) {
             if (key) {
-                printf ("%s.%s: %d\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %d\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__DEPTH, 
                         image_par->depth);
             } else {
-                printf ("%s: %d\n", GPIV_IMGPAR_KEY__DEPTH, 
+                printf ("%s %d\n", GPIV_IMGPAR_KEY__DEPTH, 
                         image_par->depth);
             }
         }
@@ -1447,44 +1451,44 @@ img_print_parameters (FILE *fp,
          */
         if (image_par->s_scale__set) {
             if (key) {
-                printf ("%s.%s: %f\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %f\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__S_SCALE, 
                         image_par->s_scale);
             } else {
-                printf ("%s: %f\n", GPIV_IMGPAR_KEY__S_SCALE, 
+                printf ("%s %f\n", GPIV_IMGPAR_KEY__S_SCALE, 
                         image_par->s_scale);
             }
         }
 
         if (image_par->t_scale__set) {
             if (key) {
-                printf ("%s.%s: %f\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %f\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__T_SCALE, 
                         image_par->t_scale);
             } else {
-                printf ("%s: %f\n", GPIV_IMGPAR_KEY__T_SCALE, 
+                printf ("%s %f\n", GPIV_IMGPAR_KEY__T_SCALE, 
                         image_par->t_scale);
             }
         }
 
         if (image_par->z_off_x__set) {
             if (key) {
-                printf ("%s.%s: %f\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %f\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__Z_OFF_X, 
                         image_par->z_off_x);
             } else {
-                printf ("%s: %f\n", GPIV_IMGPAR_KEY__Z_OFF_X, 
+                printf ("%s %f\n", GPIV_IMGPAR_KEY__Z_OFF_X, 
                         image_par->z_off_x);
             }
         }
 
         if (image_par->z_off_y__set) {
             if (key) {
-                printf ("%s.%s: %f\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %f\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__Z_OFF_Y, 
                         image_par->z_off_y);
             } else {
-                printf ("%s: %f\n", GPIV_IMGPAR_KEY__Z_OFF_Y, 
+                printf ("%s %f\n", GPIV_IMGPAR_KEY__Z_OFF_Y, 
                         image_par->z_off_y);
             }
         }
@@ -1494,140 +1498,140 @@ img_print_parameters (FILE *fp,
          */
         if (image_par->title__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__TITLE, 
                         image_par->title);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__TITLE, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__TITLE, 
                         image_par->title);
             }
         }
 
         if (image_par->creation_date__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__CREATION_DATE, 
                         image_par->creation_date);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__CREATION_DATE, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__CREATION_DATE, 
                         image_par->creation_date);
             }
         }
 
         if (image_par->location__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__LOCATION, 
                         image_par->location);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__LOCATION, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__LOCATION, 
                         image_par->location);
             }
         }
 
         if (image_par->author__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__AUTHOR, 
                         image_par->author);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__AUTHOR, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__AUTHOR, 
                         image_par->author);
             }
         }
 
         if (image_par->software__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__SOFTWARE, image_par->software);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__SOFTWARE, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__SOFTWARE, 
                         image_par->software);
             }
         }
 
         if (image_par->source__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__SOURCE, 
                         image_par->source);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__SOURCE, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__SOURCE, 
                         image_par->source);
             }
         }
 
         if (image_par->usertext__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__USERTEXT, image_par->usertext);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__USERTEXT, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__USERTEXT, 
                         image_par->usertext);
             }
         }
 
         if (image_par->warning__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__WARNING, image_par->warning);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__WARNING, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__WARNING, 
                         image_par->warning);
             }
         }
 
         if (image_par->disclaimer__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__DISCLAIMER, 
                         image_par->disclaimer);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__DISCLAIMER, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__DISCLAIMER, 
                         image_par->disclaimer);
             }
         }
 
         if (image_par->comment__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__COMMENT, 
                         image_par->comment);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__COMMENT, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__COMMENT, 
                         image_par->comment);
             }
         }
 
         if (image_par->copyright__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__COPYRIGHT, 
                         image_par->copyright);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__COPYRIGHT, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__COPYRIGHT, 
                         image_par->copyright);
             }
         }
 
         if (image_par->email__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__EMAIL, 
                         image_par->email);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__EMAIL, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__EMAIL, 
                         image_par->email);
             }
         }
 
         if (image_par->url__set) {
             if (key) {
-                printf ("%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                printf ("%s.%s %s\n", GPIV_IMGPAR_KEY, 
                         GPIV_IMGPAR_KEY__URL, 
                         image_par->url);
             } else {
-                printf ("%s: %s\n", GPIV_IMGPAR_KEY__URL, 
+                printf ("%s %s\n", GPIV_IMGPAR_KEY__URL, 
                         image_par->url);
             }
         }
@@ -1640,43 +1644,43 @@ img_print_parameters (FILE *fp,
          */
         if (image_par->ncolumns__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %d\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %d\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__NCOLUMNS, 
                          image_par->ncolumns);
             } else {
-                fprintf (fp, "%s: %d\n", GPIV_IMGPAR_KEY__NCOLUMNS, 
+                fprintf (fp, "%s %d\n", GPIV_IMGPAR_KEY__NCOLUMNS, 
                          image_par->ncolumns);
             }
         }
 
         if (image_par->nrows__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %d\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %d\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__NROWS, 
                          image_par->nrows);
             } else {
-                fprintf (fp, "%s: %d\n", GPIV_IMGPAR_KEY__NROWS, 
+                fprintf (fp, "%s %d\n", GPIV_IMGPAR_KEY__NROWS, 
                          image_par->nrows);
             }
         }
 
         if (image_par->x_corr__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %d\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %d\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__X_CORR, 
                          image_par->x_corr);
             } else {
-                fprintf (fp, "%s: %d\n", GPIV_IMGPAR_KEY__X_CORR, image_par->x_corr);
+                fprintf (fp, "%s %d\n", GPIV_IMGPAR_KEY__X_CORR, image_par->x_corr);
             }
         }
 
         if (image_par->depth__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %d\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %d\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__DEPTH, 
                          image_par->depth);
             } else {
-                fprintf (fp, "%s: %d\n", GPIV_IMGPAR_KEY__DEPTH, 
+                fprintf (fp, "%s %d\n", GPIV_IMGPAR_KEY__DEPTH, 
                          image_par->depth);
             }
         }
@@ -1686,44 +1690,44 @@ img_print_parameters (FILE *fp,
          */
         if (image_par->s_scale__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %f\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %f\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__S_SCALE, 
                          image_par->s_scale);
             } else {
-                fprintf (fp, "%s: %f\n", GPIV_IMGPAR_KEY__S_SCALE, 
+                fprintf (fp, "%s %f\n", GPIV_IMGPAR_KEY__S_SCALE, 
                          image_par->s_scale);
             }
         }
 
         if (image_par->t_scale__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %f\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %f\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__T_SCALE, 
                          image_par->t_scale);
             } else {
-                fprintf (fp, "%s: %f\n", GPIV_IMGPAR_KEY__T_SCALE, 
+                fprintf (fp, "%s %f\n", GPIV_IMGPAR_KEY__T_SCALE, 
                          image_par->t_scale);
             }
         }
 
         if (image_par->z_off_x__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %f\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %f\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__Z_OFF_X, 
                          image_par->z_off_x);
             } else {
-                fprintf (fp, "%s: %f\n", GPIV_IMGPAR_KEY__Z_OFF_X, 
+                fprintf (fp, "%s %f\n", GPIV_IMGPAR_KEY__Z_OFF_X, 
                          image_par->z_off_x);
             }
         }
 
         if (image_par->z_off_y__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %f\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %f\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__Z_OFF_Y, 
                          image_par->z_off_y);
             } else {
-                fprintf (fp, "%s: %f\n", GPIV_IMGPAR_KEY__Z_OFF_Y, 
+                fprintf (fp, "%s %f\n", GPIV_IMGPAR_KEY__Z_OFF_Y, 
                          image_par->z_off_y);
             }
         }
@@ -1733,140 +1737,140 @@ img_print_parameters (FILE *fp,
          */
         if (image_par->title__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__TITLE, 
                          image_par->title);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__TITLE, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__TITLE, 
                          image_par->title);
             }
         }
 
         if (image_par->creation_date__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__CREATION_DATE, 
                          image_par->creation_date);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__CREATION_DATE, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__CREATION_DATE, 
                          image_par->creation_date);
             }
         }
 
         if (image_par->location__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__LOCATION, 
                          image_par->location);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__LOCATION, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__LOCATION, 
                          image_par->location);
             }
         }
 
         if (image_par->author__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__AUTHOR, 
                          image_par->author);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__AUTHOR, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__AUTHOR, 
                          image_par->author);
             }
         }
 
         if (image_par->software__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__SOFTWARE, image_par->software);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__SOFTWARE, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__SOFTWARE, 
                          image_par->software);
             }
         }
 
         if (image_par->source__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__SOURCE, 
                          image_par->source);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__SOURCE, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__SOURCE, 
                          image_par->source);
             }
         }
 
         if (image_par->usertext__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__USERTEXT, image_par->usertext);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__USERTEXT, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__USERTEXT, 
                          image_par->usertext);
             }
         }
 
         if (image_par->warning__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__WARNING, image_par->warning);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__WARNING, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__WARNING, 
                          image_par->warning);
             }
         }
 
         if (image_par->disclaimer__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__DISCLAIMER, 
                          image_par->disclaimer);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__DISCLAIMER, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__DISCLAIMER, 
                          image_par->disclaimer);
             }
         }
 
         if (image_par->comment__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__COMMENT, 
                          image_par->comment);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__COMMENT, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__COMMENT, 
                          image_par->comment);
             }
         }
 
         if (image_par->copyright__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__COPYRIGHT, 
                          image_par->copyright);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__COPYRIGHT, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__COPYRIGHT, 
                          image_par->copyright);
             }
         }
 
         if (image_par->email__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__EMAIL, 
                          image_par->email);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__EMAIL, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__EMAIL, 
                          image_par->email);
             }
         }
 
         if (image_par->url__set) {
             if (key) {
-                fprintf (fp, "%s.%s: %s\n", GPIV_IMGPAR_KEY, 
+                fprintf (fp, "%s.%s %s\n", GPIV_IMGPAR_KEY, 
                          GPIV_IMGPAR_KEY__URL, 
                          image_par->url);
             } else {
-                fprintf (fp, "%s: %s\n", GPIV_IMGPAR_KEY__URL, 
+                fprintf (fp, "%s %s\n", GPIV_IMGPAR_KEY__URL, 
                          image_par->url);
             }
         }
@@ -2131,4 +2135,68 @@ obtain_imagepar_fromline (char line[],
     return;
 }
 
+#ifdef ENABLE_MPI
+void
+gpiv_img_mpi_bcast_imgpar (GpivImagePar *image_par)
+/*-----------------------------------------------------------------------------
+ * Broadcasts ONLY required image header/parameters
+ */
+{
+    if (
+        MPI_Bcast(&image_par->ncolumns, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("@&%#$!, gpiv_img_mpi_bcast_img_par: An error ocurred in MPI_Bcast");
+    }
 
+    if (
+        MPI_Bcast(&image_par->ncolumns__set, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("@&%#$!, gpiv_img_mpi_bcast_img_par: An error ocurred in MPI_Bcast");
+    }
+
+    if (
+        MPI_Bcast(&image_par->nrows, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("@&%#$!, gpiv_img_mpi_bcast_img_par: An error ocurred in MPI_Bcast");
+    }
+
+    if (
+        MPI_Bcast(&image_par->nrows__set, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("@&%#$!, gpiv_img_mpi_bcast_img_par: An error ocurred in MPI_Bcast");
+        }
+
+    if (
+        MPI_Bcast(&image_par->depth, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("@&%#$!, gpiv_img_mpi_bcast_img_par: An error ocurred in MPI_Bcast");
+        }
+
+    if (
+        MPI_Bcast(&image_par->depth__set, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("@&%#$!, gpiv_img_mpi_bcast_img_par: An error ocurred in MPI_Bcast");
+        }
+
+    if (
+        MPI_Bcast(&image_par->x_corr, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("@&%#$!, gpiv_img_mpi_bcast_img_par: An error ocurred in MPI_Bcast");
+        }
+
+    if (
+        MPI_Bcast(&image_par->x_corr__set, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("@&%#$!, gpiv_img_mpi_bcast_img_par: An error ocurred in MPI_Bcast");
+    }
+}
+
+#endif /* ENABLE_MPI */
