@@ -3,7 +3,8 @@
 /*
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of libgpiv.
    Libgpiv is free software; you can redistribute it and/or modify
@@ -29,7 +30,7 @@ EXTERNAL FUNCTIONS:      gpiv_imgproc_deform
 
 LOCAL FUNCTIONS:         compare_float
 
-LAST MODIFICATION DATE:  $Id: imgproc_deform.c,v 1.6 2007-12-19 08:46:46 gerber Exp $
+LAST MODIFICATION DATE:  $Id: imgproc_deform.c,v 1.7 2008-09-25 13:19:53 gerber Exp $
 
 -------------------------------------------------------------------------------
 
@@ -123,19 +124,26 @@ SamplesToCoefficients		(float	*Image,		/* in-place processing */
 				long	SplineDegree    /* degree of the spline model */
 				);
 
+static gchar *
+imgproc_deform_frame_from_pivdata(guint16 **img,
+                                  const GpivImagePar *image_par,
+                                  const GpivPivData *piv_data,
+                                  const gdouble magnitude
+                                  );
+
 static int
-img_deform_frame		(guint16	**img,
-				GpivImagePar	*image_par,
-				GpivPivData	*piv_data
+imgproc_deform_frame		(guint16	        **img,
+                                 const GpivImagePar	*image_par,
+                                 const GpivPivData	*piv_data
 				);
 
 static double	
 InterpolatedValue		(float	*Bcoeff,	/* input B-spline array of coefficients */
-				long	Width,		/* width of the image */
-				long	Height,		/* height of the image */
-				double	x,	      	/* x coordinate where to interpolate */
-				double	y,	       	/* y coordinate where to interpolate */
-				long	SplineDegree	/* degree of the spline model */
+				const long	Width,		/* width of the image */
+				const long	Height,		/* height of the image */
+				const double	x,	      	/* x coordinate where to interpolate */
+				const double	y,	       	/* y coordinate where to interpolate */
+				const long	SplineDegree	/* degree of the spline model */
 				);
 
 /*
@@ -154,11 +162,6 @@ gpiv_imgproc_deform (GpivImage *image,
  *---------------------------------------------------------------------------*/
 {
     gchar *err_msg = NULL;
-    gint i, j;
-    GpivPivData *pd = NULL;
-
-    gint k, l, count = 0, window = 4;
-    gfloat dy_sum, dx_sum;
 
 
     if (image->header->x_corr__set == FALSE
@@ -178,73 +181,41 @@ gpiv_imgproc_deform (GpivImage *image,
     }
 
     /*
-     * Interpolate piv data at each pixel point of the images.
+     * Deform first image frame with half shift forwards 
+     * and second frame with half shift backwards.
      */
-    pd = gpiv_alloc_pivdata (image->header->ncolumns, 
-                             image->header->nrows);
-    for (i = 0; i < pd->ny; i++) {
-        for (j = 0; j < pd->nx; j++) {
-            pd->point_x[i][j] = (float) j;
-            pd->point_y[i][j] = (float) i;
-        }
-    }
-    gpiv_piv_dxdy_at_new_grid (piv_data, pd);
-
-    /*
-     * Deform first image frame with half shift forwards.
-     */
-/*     pd2 = gpiv_cp_pivdata (pd); */
-
-#undef SMOOTH
-#ifdef SMOOTH
-    /*
-     * Smoothing
-     */
-    for (i = 0; i < pd->ny; i++) {
-        for (j = 0; j < pd->nx; j++) {
-            for (k = -window / 2; k < window / 2; k++) {
-                if (i + k > 0 && i + k < pd->ny) {
-                    for (l = -window / 2; l < window / 2; l++) {
-                        if (j + l > 0 && j + l < pd->nx) {
-                            dy_sum += pd->dy[i+k][j+l];
-                            dx_sum += pd->dx[i+k][j+l];
-                            count++;
-                        }
-                    }
-                }       
-            }
-            count = 0;
-        }
-    }
-#endif /* SMOOTH */
-
-    for (i = 0; i < pd->ny; i++) {
-        for (j = 0; j < pd->nx; j++) {
-            pd->dx[i][j] = 0.50 * pd->dx[i][j];
-            pd->dy[i][j] = 0.50 * pd->dy[i][j];
-        }
-    }
-
-    img_deform_frame (image->frame1, image->header, pd);
-
-    /*
-     * Deform second image frame with half shift backwards.
-     */
-    for (i = 0; i < pd->ny; i++) {
-        for (j = 0; j < pd->nx; j++) {
-            pd->dx[i][j] = -1.00 * pd->dx[i][j];
-            pd->dy[i][j] = -1.00 * pd->dy[i][j];
-        }
-    }
-
-    img_deform_frame (image->frame2, image->header, pd);
-
-
-    gpiv_free_pivdata (pd);
-    return (err_msg);
-#ifdef SMOOTH
-#undefine SMOOTH
+/* OK: results approved */
+#pragma omp parallel sections num_threads(2)
+    {
+#pragma omp section 
+        {
+            if ((err_msg = 
+                 imgproc_deform_frame_from_pivdata(image->frame1, image->header, 
+                                                   piv_data, 0.5))
+                != NULL) {
+#ifdef _OPENMP
+                exit;
+#else
+                return (err_msg);
 #endif
+            }
+        }
+#pragma omp section 
+        {
+            if ((err_msg = 
+                 imgproc_deform_frame_from_pivdata(image->frame2, image->header, 
+                                                   piv_data, -0.5))
+                != NULL) {
+#ifdef _OPENMP
+                exit;
+#else
+                return (err_msg);
+#endif
+            }
+        }
+    }
+
+    return (err_msg);
 }
 
 
@@ -343,10 +314,10 @@ InitialCausalCoefficient (
 static void
 GetColumn (
 	   float	*Image,		/* input image array */
-	   long	        Width,		        /* width of the image */
-	   long	        x,			/* x coordinate of the selected line */
+	   long	        Width,		/* width of the image */
+	   long	        x,		/* x coordinate of the selected line */
 	   double	Line[],		/* output linear array */
-	   long	        Height		        /* length of the line */
+	   long	        Height		/* length of the line */
 	   )
 /*--------------------------------------------------------------------------*/
 { /* begin GetColumn */
@@ -482,6 +453,8 @@ SamplesToCoefficients (
 	}
  
 
+/* BUGFIX SamplesToCoefficients: OMP causes error */
+/* #pragma omp parallel for */
 	for (y = 0L; y < Height; y++) {
 		GetRow(Image, y, Line, Width);
 		ConvertToInterpolationCoefficients(Line, Width, Pole, NbPoles, 
@@ -499,6 +472,8 @@ SamplesToCoefficients (
 	}
 
 
+/* BUGFIX SamplesToCoefficients: OMP causes error */
+/* #pragma omp parallel for */
 	for (x = 0L; x < Width; x++) {
 		GetColumn(Image, Width, x, Line, Height);
 		ConvertToInterpolationCoefficients(Line, Height, Pole, NbPoles, DBL_EPSILON);
@@ -515,11 +490,11 @@ SamplesToCoefficients (
 static double	
 InterpolatedValue(
                   float	*Bcoeff,	/* input B-spline array of coefficients */
-		  long   Width,		/* width of the image */
-		  long   Height,	/* height of the image */
-		  double x,	      	/* x coordinate where to interpolate */
-		  double y,	       	/* y coordinate where to interpolate */
-		  long SplineDegree     /* degree of the spline model */
+		  const long   Width,		/* width of the image */
+		  const long   Height,	/* height of the image */
+		  const double x,	      	/* x coordinate where to interpolate */
+		  const double y,	       	/* y coordinate where to interpolate */
+		  const long SplineDegree     /* degree of the spline model */
 		  )
 /*--------------------------------------------------------------------------*/
 {
@@ -710,11 +685,90 @@ InterpolatedValue(
 
 
 
+static gchar *
+imgproc_deform_frame_from_pivdata(guint16 **img,
+                                  const GpivImagePar *image_par,
+                                  const GpivPivData *piv_data,
+                                  const gdouble magnitude)
+/*-----------------------------------------------------------------------------
+ */
+{
+    gchar *err_msg = NULL;
+    gint i, j;
+    GpivPivData *pd = NULL;
+    gint k, l, count = 0, window = 4;
+    gfloat dy_sum, dx_sum;
+
+
+    if (img[0] == NULL) {
+        err_msg = "imgproc_deform_frame_from_pivdata: image->frame1 == NULL";
+        return (err_msg);
+    }
+
+    /*
+     * Interpolate piv data at each pixel point of the images.
+     */
+
+    pd = gpiv_alloc_pivdata (image_par->ncolumns, 
+                             image_par->nrows);
+/* OK: results approved */
+#pragma omp parallel for
+    for (i = 0; i < pd->ny; i++) {
+        for (j = 0; j < pd->nx; j++) {
+            pd->point_x[i][j] = (float) j;
+            pd->point_y[i][j] = (float) i;
+        }
+    }
+    gpiv_piv_dxdy_at_new_grid (piv_data, pd);
+
+#undef SMOOTH
+#ifdef SMOOTH
+    /*
+     * Smoothing
+     */
+    for (i = 0; i < pd->ny; i++) {
+        for (j = 0; j < pd->nx; j++) {
+            for (k = -window / 2; k < window / 2; k++) {
+                if (i + k > 0 && i + k < pd->ny) {
+                    for (l = -window / 2; l < window / 2; l++) {
+                        if (j + l > 0 && j + l < pd->nx) {
+                            dy_sum += pd->dy[i+k][j+l];
+                            dx_sum += pd->dx[i+k][j+l];
+                            count++;
+                        }
+                    }
+                }       
+            }
+            count = 0;
+        }
+    }
+#endif /* SMOOTH */
+
+/* OK: results approved */
+#pragma omp parallel for
+    for (i = 0; i < pd->ny; i++) {
+        for (j = 0; j < pd->nx; j++) {
+            pd->dx[i][j] = magnitude * pd->dx[i][j];
+            pd->dy[i][j] = magnitude * pd->dy[i][j];
+        }
+    }
+
+    imgproc_deform_frame (img, image_par, pd);
+
+
+    gpiv_free_pivdata (pd);
+#ifdef SMOOTH
+#undefine SMOOTH
+#endif
+    return (err_msg);
+}
+
+
 static int
-img_deform_frame (guint16 **img,
-                  GpivImagePar *image_par,
-                  GpivPivData *piv_data
-           )
+imgproc_deform_frame (guint16 **img,
+                      const GpivImagePar *image_par,
+                      const GpivPivData *piv_data
+                      )
 /*-----------------------------------------------------------------------------
  * DESCRIPTION:
  *      Image deformation/interpolation routine for a single image frame
@@ -733,7 +787,7 @@ img_deform_frame (guint16 **img,
  *---------------------------------------------------------------------------*/
 {
     float	*ImageRasterArray = NULL, *OutputImage = NULL;
-    float	*p, *q;
+    float	*p;
     double	x1, y1;
     long	Width = image_par->ncolumns, Height = image_par->nrows;
     long	SplineDegree = 5;
@@ -755,9 +809,13 @@ img_deform_frame (guint16 **img,
 
     ImageRasterArray = gpiv_vector (image_par->nrows * image_par->ncolumns);
     p = ImageRasterArray;
+
+/* OK: results approved */
+#pragma omp parallel for
     for (i = 0; i < image_par->nrows; i++) {
         for (j = 0; j < image_par->ncolumns; j++) {
-            *p++ = (float) img[i][j];
+            p[i*image_par->ncolumns + j] = (float) img[i][j];
+/*             *p++ = (float) img[i][j]; */
         }
     }
 
@@ -769,7 +827,7 @@ img_deform_frame (guint16 **img,
     if (Error = SamplesToCoefficients (ImageRasterArray, Width, Height, 
                                        SplineDegree)) {
         gpiv_free_vector (ImageRasterArray);
-        g_warning("LIBGPIV internal error: img_deform: Change of basis failed");
+        g_warning("LIBGPIV internal error: imgproc_deform_frame: Change of basis failed");
         return(1);
     }
 
@@ -778,6 +836,10 @@ img_deform_frame (guint16 **img,
  */
     OutputImage = gpiv_vector (image_par->nrows * image_par->ncolumns);
     p = OutputImage;
+
+/* BUGFIX imgproc_deform_frame: OMP causes differences in results */
+/* BUGFIX imgproc_deform_frame: When disabled OMP in imgproc_deform */
+/* #pragma omp parallel for private(x1, y1) */
     for (i = 0; i < image_par->nrows; i++) {
         for (j = 0; j < image_par->ncolumns; j++) {
             x1 = (double) j - (double) piv_data->dx[i][j];
@@ -787,16 +849,21 @@ img_deform_frame (guint16 **img,
                     || (((double)Width - 0.5) <= x1)
                     || (y1 <= -0.5) 
                     || (((double)Height - 0.5) <= y1)) {
-                    *p++ = 0.0F;
+/*                     *p++ = 0.0F; */
+                    p[i*image_par->ncolumns + j] = 0.0F;
                 } else {
-                    *p++ = (float)InterpolatedValue (ImageRasterArray, 
-                                                     Width, Height,
-                                                     x1, y1, SplineDegree);
+/*                     *p++ = */
+                    p[i*image_par->ncolumns + j] = 
+                        (float)InterpolatedValue (ImageRasterArray, 
+                                                  Width, Height,
+                                                  x1, y1, SplineDegree);
                 }
             } else {
-                *p++ = (float)InterpolatedValue (ImageRasterArray, 
-                                                 Width, Height,
-                                                 x1, y1, SplineDegree);
+/*                 *p++ = */
+                p[i*image_par->ncolumns + j] = 
+                    (float)InterpolatedValue (ImageRasterArray, 
+                                              Width, Height,
+                                              x1, y1, SplineDegree);
             }
 
         }
@@ -807,9 +874,11 @@ img_deform_frame (guint16 **img,
  */
 
     p = OutputImage;
+/* OK: results approved */
+#pragma omp parallel for private(rounded)
     for (i = 0; i < image_par->nrows; i++) {
         for (j = 0; j < image_par->ncolumns; j++) {
-            rounded = (long)floor ((double)*p++ + 0.5);
+            rounded = (long)floor ((double) p[i*image_par->ncolumns + j] + 0.5);
             if (rounded < 0.0) rounded = 0.0;
             if (rounded > (gfloat) img_top /* 255.0 */) rounded = (gfloat) img_top /* 255.0 */;
             img[i][j] =  (guint16) rounded;
