@@ -3,7 +3,8 @@
 /*
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of libgpiv.
    Libgpiv is free software; you can redistribute it and/or modify
@@ -35,7 +36,7 @@ EXTERNAL FUNCTIONS:
                         gpiv_imgproc_fprint_parameters
 
 
-LAST MODIFICATION DATE:  $Id: imgproc_par.c,v 1.8 2008-04-09 06:10:28 gerber Exp $
+LAST MODIFICATION DATE:  $Id: imgproc_par.c,v 1.9 2008-05-05 14:38:41 gerber Exp $
  --------------------------------------------------------------------------- */
 
 #include <gpiv.h>
@@ -208,7 +209,7 @@ gpiv_imgproc_check_parameters_read (GpivImageProcPar *image_proc_par,
             err_msg = "Using default: ";
             image_proc_par->smooth_operator = image_proc_par_default->smooth_operator;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg,
+        gpiv_warning("%s\n%s.%s %d", err_msg,
                      GPIV_IMGPROCPAR_KEY,
                      IMGPROCPAR_KEY__SMOOTH_OPERATOR,
                      image_proc_par->smooth_operator);
@@ -223,7 +224,7 @@ gpiv_imgproc_check_parameters_read (GpivImageProcPar *image_proc_par,
             err_msg = "Using default: ";
             image_proc_par->window = image_proc_par_default->window;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg,
+        gpiv_warning("%s\n%s.%s %d", err_msg,
                      GPIV_IMGPROCPAR_KEY,
                      IMGPROCPAR_KEY__WINDOW,
                      image_proc_par->window);
@@ -238,7 +239,7 @@ gpiv_imgproc_check_parameters_read (GpivImageProcPar *image_proc_par,
             err_msg = "Using default: ";
             image_proc_par->threshold = image_proc_par_default->threshold;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg,
+        gpiv_warning("%s\n%s.%s %d", err_msg,
                      GPIV_IMGPROCPAR_KEY,
                      IMGPROCPAR_KEY__THRESHOLD,
                      image_proc_par->threshold);
@@ -253,7 +254,7 @@ gpiv_imgproc_check_parameters_read (GpivImageProcPar *image_proc_par,
             err_msg = "Using default: ";
             image_proc_par->bit = image_proc_par_default->bit;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg,
+        gpiv_warning("%s\n%s.%s %d", err_msg,
                      GPIV_IMGPROCPAR_KEY,
                      IMGPROCPAR_KEY__BIT,
                       image_proc_par->bit);
@@ -355,62 +356,62 @@ print_parameters (FILE *fp,
 {
     if (fp == stdout || fp == NULL) {
         if (image_proc_par->filter__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_IMGPROCPAR_KEY, 
                     IMGPROCPAR_KEY__FILTER, 
                     image_proc_par->filter);
 
         if (image_proc_par->smooth_operator__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_IMGPROCPAR_KEY, 
                     IMGPROCPAR_KEY__SMOOTH_OPERATOR, 
                     image_proc_par->smooth_operator);
 
         if (image_proc_par->window__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_IMGPROCPAR_KEY, 
                     IMGPROCPAR_KEY__WINDOW,
                     image_proc_par->window);
 
         if (image_proc_par->threshold__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_IMGPROCPAR_KEY, 
                     IMGPROCPAR_KEY__THRESHOLD,
                     image_proc_par->threshold);
 
         if (image_proc_par->bit__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_IMGPROCPAR_KEY, 
                     IMGPROCPAR_KEY__BIT,
                     image_proc_par->bit);
 
     } else {
         if (image_proc_par->filter__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                      GPIV_IMGPROCPAR_KEY, 
                      IMGPROCPAR_KEY__FILTER, 
                      image_proc_par->filter);
 
         if (image_proc_par->smooth_operator__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                      GPIV_IMGPROCPAR_KEY, 
                      IMGPROCPAR_KEY__SMOOTH_OPERATOR, 
                      image_proc_par->smooth_operator);
 
         if (image_proc_par->window__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                      GPIV_IMGPROCPAR_KEY, 
                      IMGPROCPAR_KEY__WINDOW,
                      image_proc_par->window);
 
         if (image_proc_par->threshold__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                      GPIV_IMGPROCPAR_KEY, 
                      IMGPROCPAR_KEY__THRESHOLD,
                      image_proc_par->threshold);
 
         if (image_proc_par->bit__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                      GPIV_IMGPROCPAR_KEY, 
                      IMGPROCPAR_KEY__BIT,
                      image_proc_par->bit);
