@@ -3,7 +3,8 @@
 /*
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of libgpiv.
    Libgpiv is free software; you can redistribute it and/or modify
@@ -45,7 +46,7 @@ EXTERNAL FUNCTIONS:      gpiv_io_make_fname
 
 LOCAL FUNCTIONS:
 
-LAST MODIFICATION DATE:  $Id: io.c,v 1.17 2007-12-19 08:46:46 gerber Exp $
+LAST MODIFICATION DATE:  $Id: io.c,v 1.19 2008-09-25 13:19:53 gerber Exp $
  --------------------------------------------------------------- */
 
 #include <stdio.h>
@@ -87,7 +88,6 @@ obtain_pivdata_fromline (gchar line[],
                          guint *i,
                          guint *j
                          );
-
 static void
 obtain_pivdata_fastx_fromline (gchar line[], 
                                GpivPivData *piv_data,
@@ -102,6 +102,23 @@ obtain_scdata_fromline (gchar line[],
                         guint *j
                         );
 
+static GpivPivData *
+read_pivdata_from_file (FILE *fp,
+                        gboolean fastx
+                        );
+
+static GpivPivData *
+read_pivdata_from_stdin (gboolean fastx
+                         );
+
+static GpivScalarData *
+read_scdata_from_file (FILE *fp
+                       );
+
+static GpivScalarData *
+read_scdata_from_stdin (void
+                        );
+
 /*
  * Public functions
  */
@@ -356,6 +373,9 @@ gpiv_find_pivdata_origin (const gchar line[GPIV_MAX_CHARS]
  *      pdf:            enumerator of data origin
  *---------------------------------------------------------------------------*/
 {
+    enum GpivDataFormat pdf;
+
+
     if (strstr(line, "rr") != '\0') {
         pdf = GPIV_RR;
     } else if (strstr(line, "DaVis") != '\0') { 
@@ -389,7 +409,7 @@ gpiv_fread_pivdata       (const gchar    *fname
     }
 
     if ((piv_data = gpiv_read_pivdata (fp)) == NULL) {
-        gpiv_warning ("gpiv_fread_pivdata: failing gpiv_read_pivdata");
+        gpiv_warning ("gpiv_fread_pivdata: failing gpiv_fread_pivdata");
         return NULL;
     }
 
@@ -414,12 +434,12 @@ gpiv_fwrite_pivdata       (const gchar    *fname,
 
 
     if ((fp = fopen (fname, "wb")) == NULL) {
-        gpiv_warning ("gpiv_fread_pivdata: failing fopen %s", fname);
-        return "gpiv_fread_pivdata: failing fopen";
+        gpiv_warning ("gpiv_fwrite_pivdata: failing fopen %s", fname);
+        return "gpiv_fwrite_pivdata: failing fopen";
     }
 
     if ((err_msg = gpiv_write_pivdata (fp, piv_data, free)) != NULL) {
-/*         gpiv_warning ("gpiv_fread_pivdata: failing gpiv_read_pivdata"); */
+/*         gpiv_warning ("gpiv_fwrite_pivdata: failing gpiv_write_pivdata"); */
         return err_msg;
     }
 
@@ -440,43 +460,17 @@ gpiv_read_pivdata (FILE *fp
  *---------------------------------------------------------------------------*/
 {
     GpivPivData *piv_data = NULL;
-    gint i = 0, j = 0;
-    gchar line[GPIV_MAX_CHARS];
-
-    guint nx = 0, ny = 0;
-    gboolean scale;
-
 
 /*
- * obtain dimensions and allocate piv_data
- */
-    scale = count_asciidata (fp, &nx, &ny);
-/*     g_message ("piv_read_pivdata:: nx = %d ny = %d", nx, ny); */
-    piv_data = gpiv_alloc_pivdata (nx, ny);
-    piv_data->scale = scale;
-
-/*
- * reads the data
+ * reads the data from stdin or file pointer
  */
     if (fp == stdin || fp == NULL) {
-        while ((i < piv_data->ny - 1) || (j < piv_data->nx - 1)) {
-            gets (line);
-            obtain_pivdata_fromline (line, piv_data, &i, &j);
-        }
-        gets (line);
-        obtain_pivdata_fromline (line, piv_data, &i, &j);
-
+        piv_data = read_pivdata_from_stdin (FALSE);
     } else {
-        fseek (fp, 0, SEEK_SET);
-        while ((i < piv_data->ny - 1) || (j < piv_data->nx - 1)) {
-            fgets (line, GPIV_MAX_CHARS, fp);
-            obtain_pivdata_fromline (line, piv_data, &i, &j);
-        }
-        fgets (line, GPIV_MAX_CHARS, fp);
-        obtain_pivdata_fromline (line, piv_data, &i, &j);
-
+        piv_data = read_pivdata_from_file (fp, FALSE);
     }
 
+
     return piv_data;
 }
 
@@ -493,39 +487,18 @@ gpiv_read_pivdata_fastx (FILE *fp
  *-------------------------------------------------------------------------- */
 {
     GpivPivData *piv_data = NULL;
-    gint i = 0, j = 0;
-    gchar line[GPIV_MAX_CHARS];
-
-    guint nx, ny;
-    gboolean scale;
 
 
 /*
- * obtain dimensions and allocate piv_data
+ * reads the data from stdin or file pointer
  */
-    scale = count_asciidata (fp, &nx, &ny);
-    piv_data = gpiv_alloc_pivdata (nx, ny);
-    piv_data->scale = scale;
-
-
     if (fp == stdin || fp == NULL) {
-        while ((i < piv_data->ny - 1) || (j < piv_data->nx - 1)) {
-            gets (line);
-            obtain_pivdata_fastx_fromline (line, piv_data, &i, &j);
-        }
-        gets (line);
-        obtain_pivdata_fastx_fromline (line, piv_data, &i, &j);
-
+        piv_data = read_pivdata_from_stdin (TRUE);
     } else {
-        fseek (fp, 0, SEEK_SET);
-        while ((i < piv_data->ny - 1) || (j < piv_data->nx - 1)) {
-            fgets (line, GPIV_MAX_CHARS, fp);
-            obtain_pivdata_fastx_fromline (line, piv_data, &i, &j);
-        }
-        fgets (line, GPIV_MAX_CHARS, fp);
-        obtain_pivdata_fastx_fromline (line, piv_data, &i, &j);
+        piv_data = read_pivdata_from_file (fp, TRUE);
     }
 
+
     return piv_data;
 }
 
@@ -690,8 +663,8 @@ gpiv_fwrite_scdata      (const gchar    *fname,
 
 
     if ((fp = fopen (fname, "wb")) == NULL) {
-        gpiv_warning ("gpiv_fread_scdata: failing fopen %s", fname);
-        return "gpiv_fread_scdata: failing fopen";
+        gpiv_warning ("gpiv_fwrite_scdata: failing fopen %s", fname);
+        return "gpiv_fwrite_scdata: failing fopen";
     }
 
     if ((err_msg = gpiv_write_scdata (fp, scalar_data, free)) != NULL) {
@@ -709,42 +682,19 @@ GpivScalarData *
 gpiv_read_scdata (FILE *fp
                   )
 /*-----------------------------------------------------------------------------
- * DESCRIPTION:
- *      Reads scalar data from ascii data file
- *
- *---------------------------------------------------------------------------*/
+ * Reads scalar data from ascii data file
+ */
 {
     GpivScalarData *sc_data = NULL;
-    gint i = 0, j = 0;
-    gchar line[GPIV_MAX_CHARS];
-
-    guint nx, ny;
-    gboolean scale;    
 
 
 /*
- * obtain dimensions and allocate piv_data
+ * reads the data from stdin or file pointer
  */
-    scale = count_asciidata (fp, &nx, &ny);
-    sc_data = gpiv_alloc_scdata (nx, ny);
-    sc_data->scale = scale;
-
     if (fp == stdin || fp == NULL) {
-        while ((i < sc_data->ny - 1) || (j < sc_data->nx - 1)) {
-            gets (line);
-            obtain_scdata_fromline (line, sc_data, &i, &j);
-        }
-        gets (line);
-        obtain_scdata_fromline (line, sc_data, &i, &j);
-
+        sc_data =  read_scdata_from_stdin ();
     } else {
-        fseek (fp, 0, SEEK_SET);
-        while ((i < sc_data->ny - 1) || (j < sc_data->nx - 1)) {
-            fgets (line, GPIV_MAX_CHARS, fp);
-            obtain_scdata_fromline (line, sc_data, &i, &j);
-        }
-        fgets (line, GPIV_MAX_CHARS, fp);
-        obtain_scdata_fromline (line, sc_data, &i, &j);
+        sc_data =  read_scdata_from_file (fp);
     }
 
 
@@ -1141,7 +1091,6 @@ open_img (const gchar *fname
     gchar *ext = g_strdup(strrchr(fname, '.'));
     FILE *fp;
 
-
 #ifdef DEBUG
     g_message ("open_img:: 0 fname=%s ext=%s", fname, ext);
 #endif
@@ -1226,7 +1175,6 @@ open_img (const gchar *fname
 }
 
 
-
 static gboolean
 find_data_scaled (const gchar line[GPIV_MAX_CHARS]
                   )
@@ -1293,6 +1241,7 @@ count_asciidata (FILE *fp,
 
     if (fp == stdin || fp == NULL) {
         while (gets (line) != NULL) {
+            g_message ("count_asciidata:: line = %s", line);
             obtain_nxny_fromline (line, &scale, nx, ny, 
                                   &increment, &dat_x, &dat_y, &line_nr);
         }
@@ -1307,7 +1256,7 @@ count_asciidata (FILE *fp,
     }
 
 /*
- * Total amount of lines, including comment and empty one's
+ * Array size nx, ny
  */
     *nx = *nx + 1;
     *ny = *ny + 1;
@@ -1559,3 +1508,188 @@ obtain_scdata_fromline (gchar line[],
 
 
 
+static GpivPivData *
+read_pivdata_from_file (FILE *fp,
+                        gboolean fastx
+                        )
+/*-----------------------------------------------------------------------------
+ * Reads PIV data from file pointer
+ */
+{
+    GpivPivData *piv_data = NULL;
+    gint i = 0, j = 0;
+    gchar line[GPIV_MAX_CHARS];
+
+    guint nx = 0, ny = 0;
+    gboolean scale;
+
+
+    scale = count_asciidata (fp, &nx, &ny);
+    piv_data = gpiv_alloc_pivdata (nx, ny);
+    piv_data->scale = scale;
+
+    fseek (fp, 0, SEEK_SET);
+    while ((i < piv_data->ny - 1) || (j < piv_data->nx - 1)) {
+        fgets (line, GPIV_MAX_CHARS, fp);
+        if (fastx) {
+            obtain_pivdata_fastx_fromline (line, piv_data, &i, &j);
+        } else {
+            obtain_pivdata_fromline (line, piv_data, &i, &j);
+        }
+    }
+    fgets (line, GPIV_MAX_CHARS, fp);
+    if (fastx) {
+        obtain_pivdata_fastx_fromline (line, piv_data, &i, &j);
+    } else {
+        obtain_pivdata_fromline (line, piv_data, &i, &j);
+    }    
+
+
+    return piv_data;
+}
+
+
+static GpivPivData *
+read_pivdata_from_stdin (gboolean fastx
+                         )
+/*-----------------------------------------------------------------------------
+ * Reads PIV data from file pointer
+ */
+{
+    GpivPivData *piv_data = NULL;
+    gint i = 0, j = 0, k = 0;
+    gchar line[GPIV_MAX_LINES][GPIV_MAX_CHARS];
+
+    guint nx = 0, ny = 0;
+    gboolean scale = FALSE;
+    gulong bufsize = 2500;
+
+    gboolean increment = FALSE;
+    gfloat x = 0, y = 0;
+    gfloat dat_x = -10.0e5, dat_y = -10.0e5;
+    gint line_nr = 0; 
+
+    gboolean bool = FALSE;
+
+
+    /* 
+     * Count nx, ny, similar to count_asciidata
+     */
+
+
+    k = 0;
+    while (gets (line[k]) != NULL) {
+        obtain_nxny_fromline (line[k], &scale, &nx, &ny, 
+                              &increment, &dat_x, &dat_y, &line_nr);
+        k++;
+    }
+    nx = nx + 1;
+    ny = ny + 1;
+    piv_data = gpiv_alloc_pivdata (nx, ny);
+    piv_data->scale = scale;
+
+
+    k = 0;
+    i = 0;
+    j = 0;
+    while ((i < piv_data->ny - 1) || (j < piv_data->nx - 1)) {
+        if (fastx) {
+            obtain_pivdata_fastx_fromline (line[k], piv_data, &i, &j);
+        } else {
+            obtain_pivdata_fromline (line[k], piv_data, &i, &j);
+        }
+        k++;
+    }
+    if (fastx) {
+        obtain_pivdata_fastx_fromline (line[k], piv_data, &i, &j);
+    } else {
+        obtain_pivdata_fromline (line[k], piv_data, &i, &j);
+    }
+
+
+    return piv_data;
+}
+
+
+
+static GpivScalarData *
+read_scdata_from_file (FILE *fp
+                       )
+/*-----------------------------------------------------------------------------
+ * Reads scalar data from file pointer
+ */
+{
+    GpivScalarData *sc_data = NULL;
+    gint i = 0, j = 0;
+    gchar line[GPIV_MAX_CHARS];
+
+    guint nx = 0, ny = 0;
+    gboolean scale;
+
+
+    scale = count_asciidata (fp, &nx, &ny);
+    sc_data = gpiv_alloc_scdata (nx, ny);
+    sc_data->scale = scale;
+
+    fseek (fp, 0, SEEK_SET);
+    while ((i < sc_data->ny - 1) || (j < sc_data->nx - 1)) {
+        fgets (line, GPIV_MAX_CHARS, fp);
+        obtain_scdata_fromline (line, sc_data, &i, &j);
+    }
+    fgets (line, GPIV_MAX_CHARS, fp);
+    obtain_scdata_fromline (line, sc_data, &i, &j);
+    
+
+
+    return sc_data;
+}
+
+
+static GpivScalarData *
+read_scdata_from_stdin (void
+                        )
+/*-----------------------------------------------------------------------------
+ * Reads scalar data from stdin
+ */
+{
+    GpivScalarData *sc_data = NULL;
+    gint i = 0, j = 0, k = 0;
+    gchar line[GPIV_MAX_LINES][GPIV_MAX_CHARS];
+
+    guint nx = 0, ny = 0;
+    gboolean scale = FALSE;
+
+    gboolean increment = FALSE;
+    gfloat x = 0, y = 0;
+    gfloat dat_x = -10.0e5, dat_y = -10.0e5;
+    gint line_nr = 0; 
+
+
+/* 
+ * Count nx, ny, similar to count_asciidata
+ */
+
+    k = 0;
+    while (gets (line[k]) != NULL) {
+        obtain_nxny_fromline (line[k], &scale, &nx, &ny, 
+                              &increment, &dat_x, &dat_y, &line_nr);
+        k++;
+    }
+    nx = nx + 1;
+    ny = ny + 1;
+    sc_data = gpiv_alloc_scdata (nx, ny);
+    sc_data->scale = scale;
+
+
+    k = 0;
+    i = 0;
+    j = 0;
+    while ((i < sc_data->ny - 1) || (j < sc_data->nx - 1)) {
+       obtain_scdata_fromline (line[k], sc_data, &i, &j);
+        k++;
+    }
+    obtain_scdata_fromline (line[k], sc_data, &i, &j);
+
+
+    return sc_data;
+}
