@@ -3,7 +3,8 @@
 /*
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002,2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of libgpiv.
 
@@ -41,7 +42,7 @@ EXTERNAL FUNCTIONS:
                          gpiv_piv_fread_hdf5_parameters
                          gpiv_piv_fwrite_hdf5_parameters
 
-LAST MODIFICATION DATE:  $Id: piv_par.c,v 1.3 2008-04-09 06:10:28 gerber Exp $
+LAST MODIFICATION DATE:  $Id: piv_par.c,v 1.6 2008-09-25 13:19:53 gerber Exp $
 --------------------------------------------------------------------- */
 
 #include <gpiv.h>
@@ -320,7 +321,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->int_geo = piv_par_default->int_geo;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg,
+        gpiv_warning("%s\n%s.%s %d", err_msg,
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_GEO,
                      piv_par->int_geo);
@@ -335,7 +336,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->col_start = piv_par_default->col_start;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__COL_START,
                      piv_par->col_start);
@@ -350,7 +351,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->col_end = piv_par_default->col_end;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__COL_END,
                      piv_par->col_end);
@@ -365,7 +366,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->row_start = piv_par_default->row_start;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg,
+        gpiv_warning("%s\n%s.%s %d", err_msg,
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__ROW_START,
                      piv_par->row_start);
@@ -380,7 +381,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->row_end = piv_par_default->row_end;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__ROW_END,
                      piv_par->row_end);
@@ -396,7 +397,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->int_line_row = piv_par_default->int_line_row;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_LINE_ROW,
                      piv_par->int_line_row);
@@ -413,7 +414,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->int_line_row_start = piv_par_default->int_line_row_start;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_LINE_ROW_START,
                      piv_par->int_line_row_start);
@@ -430,7 +431,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->int_line_row_end = piv_par_default->int_line_row_end;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_LINE_ROW_END,
                      piv_par->int_line_row_end);
@@ -446,7 +447,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->int_line_col = piv_par_default->int_line_col;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_LINE_COL,
                      piv_par->int_line_col);
@@ -464,7 +465,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             piv_par->int_line_col_start = 
                 piv_par_default->int_line_col_start;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_LINE_COL_START,
                      piv_par->int_line_col_start);
@@ -481,7 +482,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->int_line_col_end = piv_par_default->int_line_col_end;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_LINE_COL_END,
                      piv_par->int_line_col_end);
@@ -497,7 +498,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->int_point_col = piv_par_default->int_point_col;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_POINT_COL,
                      piv_par->int_point_col);
@@ -513,7 +514,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             piv_par->int_point_row = piv_par_default->int_point_row;
             err_msg = "Using default: ";
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_POINT_ROW,
                      piv_par->int_point_row);
@@ -530,7 +531,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->int_size_f = piv_par_default->int_size_f;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_SIZE_F,
                      piv_par->int_size_f);
@@ -545,7 +546,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->int_size_i = piv_par_default->int_size_i;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_SIZE_I,
                      piv_par->int_size_i);
@@ -560,7 +561,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->int_shift = piv_par_default->int_shift;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_SHIFT,
                      piv_par->int_shift);
@@ -575,7 +576,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->pre_shift_col = piv_par_default->pre_shift_col;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__PRE_SHIFT_COL,
                      piv_par->pre_shift_col);
@@ -590,7 +591,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->pre_shift_row = piv_par_default->pre_shift_row;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__PRE_SHIFT_ROW,
                      piv_par->pre_shift_row);
@@ -605,7 +606,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->peak = piv_par_default->peak;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__PEAK,
                      piv_par->peak);
@@ -620,7 +621,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             piv_par->int_scheme = piv_par_default->int_scheme;
             err_msg = "Using default: ";
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__INT_SCHEME,
                      piv_par->int_scheme);
@@ -635,7 +636,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->spof_filter = piv_par_default->spof_filter;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__SPOF_FILTER,
                      piv_par->spof_filter);
@@ -651,7 +652,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->gauss_weight_ia = piv_par_default->gauss_weight_ia;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__GAUSS_WEIGHT_IA,
                      piv_par->gauss_weight_ia);
@@ -666,7 +667,7 @@ gpiv_piv_check_parameters_read (GpivPivPar *piv_par,
             err_msg = "Using default: ";
             piv_par->ifit = piv_par_default->ifit;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg, 
+        gpiv_warning("%s\n%s.%s %d", err_msg, 
                      GPIV_PIVPAR_KEY,
                      PIVPAR_KEY__IFIT,
                      piv_par->ifit);
@@ -879,27 +880,27 @@ gpiv_piv_print_parameters (FILE *fp,
  * prints to stdout
  */
         if (piv_par->int_geo__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_GEO, 
                     piv_par->int_geo);
 
         if (piv_par->col_start__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__COL_START, 
                     piv_par->col_start);
 
         if (piv_par->col_end__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__COL_END, 
                     piv_par->col_end);
 
         if (piv_par->row_start__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__ROW_START, 
                     piv_par->row_start);
 
         if (piv_par->row_end__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__ROW_END, 
                     piv_par->row_end);
 
@@ -908,21 +909,21 @@ gpiv_piv_print_parameters (FILE *fp,
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_LINE_R 
             && piv_par->int_line_row__set) 
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_LINE_ROW, 
                     piv_par->int_line_row);
 
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_LINE_C 
             && piv_par->int_line_row_start__set) 
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_LINE_ROW_START, 
                     piv_par->int_line_row_start);
 
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_LINE_C 
             && piv_par->int_line_row_end__set) 
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_LINE_ROW_END, 
                     piv_par->int_line_row_end);
     
@@ -931,21 +932,21 @@ gpiv_piv_print_parameters (FILE *fp,
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_LINE_C 
             && piv_par->int_line_col__set) 
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_LINE_COL, 
                     piv_par->int_line_col);
 
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_LINE_R 
             && piv_par->int_line_col_start__set) 
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_LINE_COL_START, 
                     piv_par->int_line_col_start);
 
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_LINE_R 
             && piv_par->int_line_col_end__set) 
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_LINE_COL_END, 
                     piv_par->int_line_col_end);
     
@@ -954,7 +955,7 @@ gpiv_piv_print_parameters (FILE *fp,
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_POINT 
             && piv_par->int_point_row__set)
-            printf ("%s.%s: %d\n",
+            printf ("%s.%s %d\n",
                                   
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_POINT_ROW, 
                     piv_par->int_point_row);
@@ -962,66 +963,66 @@ gpiv_piv_print_parameters (FILE *fp,
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_POINT 
             && piv_par->int_point_col__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_POINT_COL,
                     piv_par->int_point_col);
 
 
 
         if (piv_par->int_size_f__set)
-            printf ("%s.%s: %d\n",
+            printf ("%s.%s %d\n",
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_SIZE_F, 
                     piv_par->int_size_f);
 
         if (piv_par->int_size_i__set)
-            printf ("%s.%s: %d\n",
+            printf ("%s.%s %d\n",
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_SIZE_I, 
                     piv_par->int_size_i);
 
         if (piv_par->int_shift__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_SHIFT, 
                     piv_par->int_shift);
 
         if (piv_par->int_scheme__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_SCHEME, 
                     piv_par->int_scheme);
 
         if (piv_par->spof_filter__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__SPOF_FILTER, 
                     piv_par->spof_filter);
 
         if (piv_par->gauss_weight_ia__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__GAUSS_WEIGHT_IA, 
                     piv_par->gauss_weight_ia);
 
         if (piv_par->pre_shift_col__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__PRE_SHIFT_COL, 
                     piv_par->pre_shift_col);
 
         if (piv_par->pre_shift_row__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__PRE_SHIFT_ROW, 
                     piv_par->pre_shift_row);
 
         if (piv_par->ifit__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__IFIT, 
                     piv_par->ifit);
 
 
 
         if (piv_par->peak__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__PEAK, 
                     piv_par->peak);
 
         if (piv_par->print_piv__set)
-            printf ("%s.%s: %d\n", 
+            printf ("%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, "Print_piv", 
                     piv_par->print_piv);
 
@@ -1030,27 +1031,27 @@ gpiv_piv_print_parameters (FILE *fp,
  * prints to fp
  */
         if (piv_par->int_geo__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_GEO, 
                     piv_par->int_geo);
 
         if (piv_par->col_start__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__COL_START, 
                     piv_par->col_start);
 
         if (piv_par->col_end__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__COL_END, 
                     piv_par->col_end);
 
         if (piv_par->row_start__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__ROW_START, 
                     piv_par->row_start);
 
         if (piv_par->row_end__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__ROW_END, 
                     piv_par->row_end);
 
@@ -1059,21 +1060,21 @@ gpiv_piv_print_parameters (FILE *fp,
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_LINE_R 
             && piv_par->int_line_row__set) 
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_LINE_ROW, 
                     piv_par->int_line_row);
 
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_LINE_C 
             && piv_par->int_line_row_start__set) 
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_LINE_ROW_START, 
                     piv_par->int_line_row_start);
 
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_LINE_C 
             && piv_par->int_line_row_end__set) 
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_LINE_ROW_END, 
                     piv_par->int_line_row_end);
     
@@ -1082,21 +1083,21 @@ gpiv_piv_print_parameters (FILE *fp,
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_LINE_C 
             && piv_par->int_line_col__set) 
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_LINE_COL, 
                     piv_par->int_line_col);
 
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_LINE_R 
             && piv_par->int_line_col_start__set) 
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_LINE_COL_START, 
                     piv_par->int_line_col_start);
 
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_LINE_R 
             && piv_par->int_line_col_end__set) 
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_LINE_COL_END, 
                     piv_par->int_line_col_end);
     
@@ -1105,7 +1106,7 @@ gpiv_piv_print_parameters (FILE *fp,
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_POINT 
             && piv_par->int_point_row__set)
-            fprintf (fp, "%s.%s: %d\n",
+            fprintf (fp, "%s.%s %d\n",
                                   
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_POINT_ROW, 
                     piv_par->int_point_row);
@@ -1113,65 +1114,65 @@ gpiv_piv_print_parameters (FILE *fp,
         if (piv_par->int_geo__set
             && piv_par->int_geo == GPIV_POINT 
             && piv_par->int_point_col__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_POINT_COL,
                     piv_par->int_point_col);
 
 
 
         if (piv_par->int_size_f__set)
-            fprintf (fp, "%s.%s: %d\n",
+            fprintf (fp, "%s.%s %d\n",
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_SIZE_F, 
                     piv_par->int_size_f);
 
         if (piv_par->int_size_i__set)
-            fprintf (fp, "%s.%s: %d\n",
+            fprintf (fp, "%s.%s %d\n",
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_SIZE_I, 
                     piv_par->int_size_i);
 
         if (piv_par->int_shift__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_SHIFT, 
                     piv_par->int_shift);
 
         if (piv_par->int_scheme__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__INT_SCHEME, 
                     piv_par->int_scheme);
 
         if (piv_par->spof_filter__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__SPOF_FILTER, 
                     piv_par->spof_filter);
 
         if (piv_par->gauss_weight_ia__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__GAUSS_WEIGHT_IA, 
                     piv_par->gauss_weight_ia);
 
         if (piv_par->pre_shift_col__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__PRE_SHIFT_COL, 
                     piv_par->pre_shift_col);
 
         if (piv_par->pre_shift_row__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__PRE_SHIFT_ROW, 
                     piv_par->pre_shift_row);
 
         if (piv_par->ifit__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__IFIT, 
                     piv_par->ifit);
 
 
         if (piv_par->peak__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, PIVPAR_KEY__PEAK, 
                     piv_par->peak);
 
         if (piv_par->print_piv__set)
-            fprintf (fp, "%s.%s: %d\n", 
+            fprintf (fp, "%s.%s %d\n", 
                     GPIV_PIVPAR_KEY, "Print_piv", 
                     piv_par->print_piv);
     }
@@ -1527,6 +1528,150 @@ gpiv_piv_fwrite_hdf5_parameters (const gchar *fname,
 }
 
 
+#ifdef ENABLE_MPI
+gchar *
+gpiv_piv_mpi_bcast_pivpar (GpivPivPar *piv_par)
+/*-----------------------------------------------------------------------------
+ * Broadcasts piv_par, usring root as 0 and MPI_COMM_WORLD
+ */
+{
+    gchar *err_msg = NULL;
+    gint root = 0;
+
+    if (
+        MPI_Bcast(&piv_par->int_geo, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_geo__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->col_start, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->col_start__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->col_end, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->col_end__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->row_start, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->row_start__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->row_end, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->row_end__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->int_line_col, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_line_col__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+ 
+        || MPI_Bcast(&piv_par->int_line_col_start, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_line_col_start__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->int_line_col_end, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_line_col_end__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->int_line_row, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_line_row__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->int_line_row_start, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_line_row_start__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->int_line_row_end, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_line_row_end__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->int_point_col, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_point_col__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+ 
+        || MPI_Bcast(&piv_par->int_point_row, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_point_row__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->int_size_f, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_size_f__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->int_size_i, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_size_i__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->int_shift, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_shift__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->int_deform, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_deform__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->spline_degree, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->spline_degree__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->pre_shift_col, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->pre_shift_col__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->pre_shift_row, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->pre_shift_row__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->ifit, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->ifit__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->peak, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->peak__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->int_scheme__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->int_scheme, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->gauss_weight_ia, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->gauss_weight_ia__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&piv_par->spof_filter, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&piv_par->spof_filter__set, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_warning("THOUSAND BOMBS AND SHELLS!");
+        err_msg = "gpiv_piv_mpi_bcast_pivpar: An error ocurred in MPI_Bcast";
+    }
+
+    return err_msg;
+}
+#endif /* ENABLE_MPI */
+
 /*
  * Local functions
  */
@@ -2163,5 +2308,3 @@ obtain_pivpar_fromline (char line[],
 
     return;
 }
-
-
