@@ -3,7 +3,8 @@
 /*
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of libgpiv.
    Libgpiv is free software; you can redistribute it and/or modify
@@ -35,7 +36,15 @@ EXTERNAL FUNCTIONS:
                          gpiv_add_dxdy_pivdata
                          gpiv_sum_dxdy_pivdata
 
-LAST MODIFICATION DATE:  $Id: piv_utils.c,v 1.2 2007-12-19 08:46:46 gerber Exp $
+                         gpiv_piv_mpi_scatter_pivdata
+                         gpiv_piv_mpi_gather_pivdata
+                         gpiv_piv_mpi_compute_counts
+                         gpiv_piv_mpi_compute_displs
+                         gpiv_piv_mpi_scatterv_pivdata
+                         gpiv_piv_mpi_gatherv_pivdata
+                         gpiv_piv_mpi_bcast_pivdata
+
+LAST MODIFICATION DATE:  $Id: piv_utils.c,v 1.3 2008-09-25 13:19:53 gerber Exp $
  --------------------------------------------------------------------------- */
 
 #include <gpiv.h>
@@ -85,7 +94,7 @@ gpiv_alloc_pivdata (const guint nx,
  */
 {
     GpivPivData *piv_data = g_new0 (GpivPivData, 1);
-    guint i, j;
+    gint i, j;
 
 
     if (ny <= 0 || nx <= 0) {
@@ -106,6 +115,7 @@ gpiv_alloc_pivdata (const guint nx,
 /*
  * Initializing values for structure members
  */
+#pragma omp parallel for
     for (i = 0; i < piv_data->ny; i++) {
         for (j = 0; j < piv_data->nx; j++) {
             piv_data->point_x[i][j] = 0.0;
@@ -229,7 +239,7 @@ gpiv_cp_pivdata (const GpivPivData *piv_data
 {
     GpivPivData *piv_data_out = NULL;
     gchar *err_msg = NULL;
-    guint i, j;
+    gint i, j;
 
 
     if ((err_msg = gpiv_check_alloc_pivdata (piv_data)) != NULL) {
@@ -243,6 +253,7 @@ gpiv_cp_pivdata (const GpivPivData *piv_data
         return NULL;
     }
 
+#pragma omp parallel for
     for (i = 0; i < piv_data_out->ny; i++) {
         for (j = 0; j < piv_data_out->nx; j++) {
             piv_data_out->point_x[i][j] = piv_data->point_x[i][j];
@@ -280,7 +291,7 @@ gpiv_ovwrt_pivdata (const GpivPivData *piv_data_in,
  *---------------------------------------------------------------------------*/
 {
     gchar *err_msg = NULL;
-    guint i, j;
+    gint i, j;
 
 
     if (piv_data_in->nx != piv_data_out->nx
@@ -310,6 +321,7 @@ gpiv_ovwrt_pivdata (const GpivPivData *piv_data_in,
 /*
  * Overwriting
  */
+#pragma omp parallel for
     for (i = 0; i < piv_data_in->ny; i++) {
         for (j = 0; j < piv_data_in->nx; j++) {
             piv_data_out->point_x[i][j] = piv_data_in->point_x[i][j];
@@ -390,6 +402,7 @@ gpiv_0_pivdata (GpivPivData *piv_data
     }
 
 
+#pragma omp parallel for
     for (i = 0; i < piv_data->ny; i++) {
         for (j = 0; j < piv_data->nx; j++) {
             /*             piv_data->point_x[i][j] = 0.0; */
@@ -437,6 +450,7 @@ gpiv_add_dxdy_pivdata (const GpivPivData *piv_data_in,
         return err_msg;
     }
 
+#pragma omp parallel for
     for (i = 0; i < piv_data_out->ny; i++) {
         for (j = 0; j < piv_data_out->nx; j++) {
             piv_data_out->point_x[i][j] = piv_data_in->point_x[i][j];
@@ -474,6 +488,7 @@ gpiv_sum_dxdy_pivdata (const GpivPivData *gpd,
     }
 
 
+#pragma omp parallel for
     for (i = 0; i < gpd->ny; i++) {
         for (j = 0; j < gpd->nx; j++) {
             *sum += gpd->dx[i][j];
@@ -597,7 +612,6 @@ gpiv_alloc_cov          (const guint int_size0,
 /*---------------------------------------------------------------------------*/
 {
     GpivCov *cov = g_new0 (GpivCov, 1);
-    guint i, j;
 
     bounds_cov (cov, int_size0, x_corr);
     cov->z = gpiv_matrix_index (cov->z_rl, cov->z_rh, cov->z_cl, cov->z_ch);
@@ -678,3 +692,391 @@ bounds_cov (GpivCov *cov,
     cov->z_cl = cov->z_cnl - int_size_0;
     cov->z_ch = cov->z_cph;
 }
+
+
+#ifdef ENABLE_MPI
+void
+gpiv_piv_mpi_scatter_pivdata (GpivPivData *pd, 
+                     GpivPivData *pd_scat, 
+                     guint nprocs)
+/*-----------------------------------------------------------------------------
+  Scatters PivData structure for parallel processing with mpi
+  (NOT: except of pd->nx and pd->ny, which should broadcasted in forward
+  in order to allocate memory.)
+
+  INPUT:
+  pd 
+  nprocs: number of processes
+
+  OUTPUT:
+  pd_scat: scattered piv data
+*/
+{
+    gint root = 0;
+
+
+    if (MPI_Scatter(*pd->point_x, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, 
+                    *pd_scat->point_x, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, root, 
+                    MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error("mpi_scatter_pivdata: An error ocurred in MPI_Scatter for point_x");
+    }
+
+    if (MPI_Scatter(*pd->point_y, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, 
+                    *pd_scat->point_y, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, root, 
+                    MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error("mpi_scatter_pivdata: An error ocurred in MPI_Scatter for point_y");
+    }
+
+    if (MPI_Scatter(*pd->dx, (pd->nx * pd->ny) / nprocs, MPI_FLOAT, 
+                    *pd_scat->dx, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, root, 
+                    MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error("mpi_scatter_pivdata: An error ocurred in MPI_Scatter for dx");
+    }
+
+    if (MPI_Scatter(*pd->dy, (pd->nx * pd->ny) / nprocs, MPI_FLOAT, 
+                    *pd_scat->dy, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, root, 
+                    MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error("mpi_scatter_pivdata: An error ocurred in MPI_Scatter for dy");
+    }
+
+    if (MPI_Scatter(*pd->snr, (pd->nx * pd->ny) / nprocs, MPI_FLOAT, 
+                    *pd_scat->snr, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, root, 
+                    MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error("mpi_scatter_pivdata: An error ocurred in MPI_Scatter for snr");
+    }
+
+    if (MPI_Scatter(*pd->peak_no, (pd->nx * pd->ny) / nprocs, MPI_INT, 
+                    *pd_scat->peak_no, (pd->nx * pd->ny)/nprocs, MPI_INT, root, 
+                    MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("mpi_scatter_pivdata: An error ocurred in MPI_Scatter for peak_no");
+    }
+}
+
+
+void 
+gpiv_piv_mpi_gather_pivdata (GpivPivData *pd_scat, 
+                    GpivPivData *pd, 
+                    guint nprocs)
+/*-----------------------------------------------------------------------------
+ Gathers PivData structure for parallel processing with mpi.
+
+ INPUT:
+ pd_scat: scattered piv data
+
+ OUTPUT:
+ pd: 
+*/
+{
+    gint root = 0;
+
+
+    if (MPI_Gather(*pd_scat->point_x, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, 
+                   *pd->point_x, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("Libgpiv: mpi_gather_pivdata: An error ocurred in MPI_Gather");
+    }
+
+    if (MPI_Gather(*pd_scat->point_y, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, 
+                   *pd->point_y, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("Libgpiv: mpi_gather_pivdata: An error ocurred in MPI_Gather");
+    }
+
+    if (MPI_Gather(*pd_scat->dx, (pd->nx * pd->ny) / nprocs, MPI_FLOAT, 
+                   *pd->dx, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("Libgpiv: mpi_gather_pivdata: An error ocurred in MPI_Gather");
+    }
+
+    if (MPI_Gather(*pd_scat->dy, (pd->nx * pd->ny) / nprocs, MPI_FLOAT, 
+                   *pd->dy, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error ("Libgpiv: mpi_gather_pivdata: An error ocurred in MPI_Gather");
+    }
+
+    if (MPI_Gather(*pd_scat->snr, (pd->nx * pd->ny) / nprocs, MPI_FLOAT, 
+                   *pd->snr, (pd->nx * pd->ny)/nprocs, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("Libgpiv: mpi_gather_pivdata: An error ocurred in MPI_Gather");
+    }
+
+    if (MPI_Gather(*pd_scat->peak_no, (pd->nx * pd->ny) / nprocs, MPI_INT, 
+                   *pd->peak_no, (pd->nx * pd->ny)/nprocs, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("Libgpiv: mpi_gather_pivdata: An error ocurred in MPI_Gather");
+    }
+}
+
+
+
+gint * 
+gpiv_piv_mpi_compute_counts(const guint nx, 
+                            const guint ny)
+/*-----------------------------------------------------------------------------
+ * Calculates counts and displc for scatterv rows of data
+ */
+{
+    gint *counts = NULL;
+    gint i, nprocs, rank;
+
+
+    MPI_Comm_size(MPI_COMM_WORLD, &nprocs);
+    MPI_Comm_size(MPI_COMM_WORLD, &rank);
+
+    counts = gpiv_ivector (nprocs);
+    counts[0] = (ny  / nprocs + (0 < (ny)%nprocs ? 1 : 0)) * nx;
+#ifdef DEBUG
+    if (rank ==0) g_message ("mpi_compute_counts:: counts[0] = %d", 
+                             counts[0]);
+#endif
+
+    for (i = 1; i < nprocs; i++) {
+        counts[i] = (ny  / nprocs + (i < (ny)%nprocs ? 1 : 0)) * nx;
+#ifdef DEBUG
+        if (rank ==0) g_message ("mpi_compute_counts:: counts[%d] = %d", 
+                                 i, counts[i]);
+#endif
+    }
+
+
+    return counts;
+}
+
+
+gint *
+gpiv_piv_mpi_compute_displs(gint *counts, 
+                            const guint nx, 
+                            const guint ny)
+/*-----------------------------------------------------------------------------
+ * Calculates displc for scatterv rows of data
+ * As rows are scattered, nx is needed for correctly calculation of 
+ * displacements
+ */
+{
+    gint *displs = NULL;
+    gint i, nprocs, rank;
+
+
+    MPI_Comm_size(MPI_COMM_WORLD, &nprocs);
+    MPI_Comm_size(MPI_COMM_WORLD, &rank);
+
+    displs = gpiv_ivector (nprocs);
+    displs[0] = 0;
+#ifdef DEBUG
+    if (rank ==0) g_message ("mpi_compute_displs:: counts[0] = %d", 
+                             displs[0]);
+#endif
+
+    for (i = 1; i < nprocs; i++) {
+        displs[i] = displs[i-1] + counts[i-1];
+#ifdef DEBUG
+        if (rank ==0) g_message ("mpi_compute_displs:: displs[%d] = %d", 
+                                 i, displs[i]);
+#endif
+    }
+
+
+    return displs;
+}
+
+
+void
+gpiv_piv_mpi_scatterv_pivdata (GpivPivData *pd, 
+                               GpivPivData *pd_scat, 
+                               gint *counts,
+                               gint *displs)
+/*-----------------------------------------------------------------------------
+  Scatters PivData structure for parallel processing with mpi
+  except of pd->nx and pd->ny, which should already be broadcasted for
+  memory allocation.)
+
+  INPUT:
+  pd 
+  nprocs: number of processes
+
+  OUTPUT:
+  pd_scat: scattered piv data
+*/
+{
+    gint root = 0, rank;
+
+
+
+    MPI_Comm_rank(MPI_COMM_WORLD, &rank);
+#ifdef DEBUG
+    g_message ("mpi_scatterv_pivdata:: rank=%d counts[%d]=%d nx=%d ny=%d", 
+               rank, rank, counts[rank], pd_scat->nx, pd_scat->ny);
+#endif
+
+    if (MPI_Scatterv(*pd->point_x, counts, displs, MPI_FLOAT, 
+                    *pd_scat->point_x, counts[rank], MPI_FLOAT, root, 
+                    MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error("mpi_scatterv_pivdata: An error ocurred in MPI_Scatter for point_x");
+    }
+
+    if (MPI_Scatterv(*pd->point_y, counts, displs, MPI_FLOAT, 
+                    *pd_scat->point_y, counts[rank], MPI_FLOAT, root, 
+                    MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error("mpi_scatterv_pivdata: An error ocurred in MPI_Scatter for point_y");
+    }
+
+    if (MPI_Scatterv(*pd->dx, counts, displs, MPI_FLOAT, 
+                    *pd_scat->dx, counts[rank], MPI_FLOAT, root, 
+                    MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error("mpi_scatterv_pivdata: An error ocurred in MPI_Scatter for dx");
+    }
+
+    if (MPI_Scatterv(*pd->dy, counts, displs, MPI_FLOAT, 
+                    *pd_scat->dy, counts[rank], MPI_FLOAT, root, 
+                    MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error("mpi_scatterv_pivdata: An error ocurred in MPI_Scatter for dy");
+    }
+
+    if (MPI_Scatterv(*pd->snr, counts, displs, MPI_FLOAT, 
+                    *pd_scat->snr, counts[rank], MPI_FLOAT, root, 
+                    MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error("mpi_scatterv_pivdata: An error ocurred in MPI_Scatter for snr");
+    }
+
+    if (MPI_Scatterv(*pd->peak_no, counts, displs, MPI_INT, 
+                    *pd_scat->peak_no, counts[rank], MPI_INT, root, 
+                    MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("mpi_scatterv_pivdata: An error ocurred in MPI_Scatter for peak_no");
+    }
+
+}
+
+
+
+void 
+gpiv_piv_mpi_gatherv_pivdata (GpivPivData *pd_scat, 
+                              GpivPivData *pd, 
+                              gint *counts,
+                              gint *displs)
+/*-----------------------------------------------------------------------------
+ Gathers PivData structure for parallel processing with mpi
+
+ INPUT:
+ pd_scat: scattered piv data
+ comm: mpi common
+
+ OUTPUT:
+ pd: 
+*/
+{
+    gint root = 0, rank;
+
+
+
+    MPI_Comm_rank(MPI_COMM_WORLD, &rank);
+#ifdef DEBUG
+    g_message ("mpi_gatherv_pivdata:: 0 rank=%d counts[%d]=%d", 
+               rank, rank, counts[rank]);
+#endif
+
+    if (MPI_Gatherv(*pd_scat->point_x, counts[rank], MPI_FLOAT, 
+                   *pd->point_x, counts, displs, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("Libgpiv: mpi_gatherv_pivdata: An error ocurred in MPI_Gather");
+    }
+
+    if (MPI_Gatherv(*pd_scat->point_y, counts[rank], MPI_FLOAT, 
+                   *pd->point_y, counts, displs, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("Libgpiv: mpi_gatherv_pivdata: An error ocurred in MPI_Gather");
+    }
+
+    if (MPI_Gatherv(*pd_scat->dx, counts[rank], MPI_FLOAT, 
+                   *pd->dx, counts, displs, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("Libgpiv: mpi_gatherv_pivdata: An error ocurred in MPI_Gather");
+    }
+
+    if (MPI_Gatherv(*pd_scat->dy, counts[rank], MPI_FLOAT, 
+                   *pd->dy, counts, displs, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error ("Libgpiv: mpi_gatherv_pivdata: An error ocurred in MPI_Gather");
+    }
+
+    if (MPI_Gatherv(*pd_scat->snr, counts[rank], MPI_FLOAT, 
+                   *pd->snr, counts, displs, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("Libgpiv: mpi_gatherv_pivdata: An error ocurred in MPI_Gather");
+    }
+
+    if (MPI_Gatherv(*pd_scat->peak_no, counts[rank], MPI_INT, 
+                   *pd->peak_no, counts, displs, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("Libgpiv: mpi_gatherv_pivdata: An error ocurred in MPI_Gather");
+    }
+}
+
+
+
+void 
+gpiv_piv_mpi_bcast_pivdata (GpivPivData *pd
+                   )
+/*-----------------------------------------------------------------------------
+ Gathers PivData structure for parallel processing with mpi
+ */
+{
+    gint root = 0;
+
+
+    if (
+        MPI_Bcast(*pd->point_x, pd->nx * pd->ny, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("Libgpiv: mpi_bcast_pivdata: An error ocurred in MPI_Bcast");
+    }
+
+    if (
+        MPI_Bcast(*pd->point_y, pd->nx * pd->ny, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("Libgpiv: mpi_bcast_pivdata: An error ocurred in MPI_Bcast");
+    }
+
+    if (
+        MPI_Bcast(*pd->dx, pd->nx * pd->ny, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("Libgpiv: mpi_bcast_pivdata: An error ocurred in MPI_Bcast");
+    }
+
+    if (
+        MPI_Bcast(*pd->dy, pd->nx * pd->ny, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("Libgpiv: mpi_bcast_pivdata: An error ocurred in MPI_Bcast");
+    }
+
+    if (
+        MPI_Bcast(*pd->snr, pd->nx * pd->ny, MPI_FLOAT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("Libgpiv: mpi_bcast_pivdata: An error ocurred in MPI_Bcast");
+    }
+
+    if (
+        MPI_Bcast(*pd->peak_no, pd->nx * pd->ny, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        ) {
+        gpiv_error("Libgpiv: mpi_bcast_pivdata: An error ocurred in MPI_Bcast");
+    }
+}
+#endif /* ENABLE_MPI */
