@@ -3,7 +3,8 @@
 /*
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of libgpiv.
    Libgpiv is free software; you can redistribute it and/or modify
@@ -38,7 +39,7 @@ EXTERNAL FUNCTIONS:
                         gpiv_post_fread_hdf_parameters
                         gpiv_post_fwrite_hdf_parameters
 
-LAST MODIFICATION DATE: $Id: post_par.c,v 1.7 2008-04-09 06:10:28 gerber Exp $
+LAST MODIFICATION DATE: $Id: post_par.c,v 1.8 2008-05-05 14:38:42 gerber Exp $
  ------------------------------------------------------------------- */
 
 #include <gpiv.h>
@@ -338,7 +339,7 @@ gpiv_post_check_parameters_read (GpivPostPar *post_par,
             err_msg = "Using default: ";
             post_par->operator_manipiv = post_par_default->operator_manipiv;
         }
-        gpiv_warning("%s\n%s.%s: %d", 
+        gpiv_warning("%s\n%s.%s %d", 
                      err_msg, 
                      GPIV_POSTPAR_KEY,
                      POSTPAR_KEY__OPERATOR_MANIPIV,
@@ -355,7 +356,7 @@ gpiv_post_check_parameters_read (GpivPostPar *post_par,
             err_msg = "Using default: ";
             post_par->set = post_par_default->set;
         }
-        gpiv_warning("%s\n%s.%s: %d", 
+        gpiv_warning("%s\n%s.%s %d", 
                      err_msg, 
                      GPIV_POSTPAR_KEY,
                      POSTPAR_KEY__SET,
@@ -372,7 +373,7 @@ gpiv_post_check_parameters_read (GpivPostPar *post_par,
             err_msg = "Using default: ";
             post_par->set_dx = post_par_default->set_dx;
         }
-        gpiv_warning("%s\n%s.%s: %f", 
+        gpiv_warning("%s\n%s.%s %f", 
                      err_msg, 
                      GPIV_POSTPAR_KEY,
                      POSTPAR_KEY__SET_DX,
@@ -389,7 +390,7 @@ gpiv_post_check_parameters_read (GpivPostPar *post_par,
             err_msg = "Using default: ";
             post_par->set_dy = post_par_default->set_dy;
         }
-        gpiv_warning("%s\n%s.%s: %f", 
+        gpiv_warning("%s\n%s.%s %f", 
                      err_msg, 
                      GPIV_POSTPAR_KEY,
                      POSTPAR_KEY__SET_DY,
@@ -409,7 +410,7 @@ gpiv_post_check_parameters_read (GpivPostPar *post_par,
             err_msg = "Using default: ";
             post_par->subtract = post_par_default->subtract;
         }
-        gpiv_warning("%s\n%s.%s: %d", 
+        gpiv_warning("%s\n%s.%s %d", 
                      err_msg, 
                      GPIV_POSTPAR_KEY,
                      POSTPAR_KEY__SUBTRACT,
@@ -425,7 +426,7 @@ gpiv_post_check_parameters_read (GpivPostPar *post_par,
             err_msg = "Using default: ";
             post_par->z_off_dx = post_par_default->z_off_dx;
         }
-        gpiv_warning("%s\n%s.%s: %f", 
+        gpiv_warning("%s\n%s.%s %f", 
                      err_msg, 
                      GPIV_POSTPAR_KEY,
                      POSTPAR_KEY__Z_OFF_DX,
@@ -441,7 +442,7 @@ gpiv_post_check_parameters_read (GpivPostPar *post_par,
             err_msg = "Using default: ";
             post_par->z_off_dy = post_par_default->z_off_dy;
         }
-        gpiv_warning("%s\n%s.%s: %f", 
+        gpiv_warning("%s\n%s.%s %f", 
                      err_msg, 
                      GPIV_POSTPAR_KEY,
                      POSTPAR_KEY__Z_OFF_DY,
@@ -461,7 +462,7 @@ gpiv_post_check_parameters_read (GpivPostPar *post_par,
             err_msg = "Using default: ";
             post_par->diff_type = post_par_default->diff_type;
         }
-        gpiv_warning("%s\n%s.%s: %d", 
+        gpiv_warning("%s\n%s.%s %d", 
                      err_msg, 
                      GPIV_POSTPAR_KEY,
                      POSTPAR_KEY__DIFF_TYPE,
@@ -478,7 +479,7 @@ gpiv_post_check_parameters_read (GpivPostPar *post_par,
             err_msg = "Using default: ";
             post_par->operator_vorstra = post_par_default->operator_vorstra;
         }
-        gpiv_warning("%s\n%s.%s: %d", 
+        gpiv_warning("%s\n%s.%s %d", 
                      err_msg, 
                      GPIV_POSTPAR_KEY,
                      POSTPAR_KEY__OPERATOR_VORSTRA,
@@ -497,7 +498,7 @@ gpiv_post_check_parameters_read (GpivPostPar *post_par,
             err_msg = "Using default: ";
             post_par->scale_type = post_par_default->scale_type;
         }
-        gpiv_warning("%s\n%s.%s: %d", 
+        gpiv_warning("%s\n%s.%s %d", 
                      err_msg, 
                      GPIV_POSTPAR_KEY,
                      POSTPAR_KEY__SCALE_TYPE,
@@ -532,25 +533,25 @@ gpiv_post_print_parameters (FILE *fp,
      * Parameters for manipiv
      */
     if (post_par->operator_manipiv__set)
-        fprintf(fp,"%s.%s:  %d\n", 
+        fprintf(fp,"%s.%s  %d\n", 
                 GPIV_POSTPAR_KEY, 
                 POSTPAR_KEY__OPERATOR_MANIPIV, 
                 post_par->operator_manipiv);
     
     if (post_par->set__set)
-        fprintf(fp,"%s.%s:  %d\n", 
+        fprintf(fp,"%s.%s  %d\n", 
                 GPIV_POSTPAR_KEY, 
                 POSTPAR_KEY__SET, 
                 post_par->set);
     
     if (post_par->set_dx__set)
-        fprintf(fp,"%s.%s:  %f\n", 
+        fprintf(fp,"%s.%s  %f\n", 
                 GPIV_POSTPAR_KEY, 
                 POSTPAR_KEY__SET_DX, 
                 post_par->set_dx);
     
     if (post_par->set_dy__set)
-        fprintf(fp,"%s.%s:  %f\n", 
+        fprintf(fp,"%s.%s  %f\n", 
                 GPIV_POSTPAR_KEY, 
                 POSTPAR_KEY__SET_DY, 
                 post_par->set_dy);
@@ -559,19 +560,19 @@ gpiv_post_print_parameters (FILE *fp,
      * Parameters of s-avg
      */
     if (post_par->subtract__set) 
-        fprintf(fp,"%s.%s: %d\n",
+        fprintf(fp,"%s.%s %d\n",
                 GPIV_POSTPAR_KEY, 
                 POSTPAR_KEY__SUBTRACT, 
                 post_par->subtract);
     
     if (post_par->z_off_dx__set) 
-        fprintf(fp,"%s.%s: %f\n",
+        fprintf(fp,"%s.%s %f\n",
                 GPIV_POSTPAR_KEY, 
                 POSTPAR_KEY__Z_OFF_DX, 
                 post_par->z_off_dx);
     
     if (post_par->z_off_dy__set) 
-        fprintf(fp,"%s.%s: %f\n",
+        fprintf(fp,"%s.%s %f\n",
                 GPIV_POSTPAR_KEY, 
                 POSTPAR_KEY__Z_OFF_DY, 
                 post_par->z_off_dy);
@@ -580,13 +581,13 @@ gpiv_post_print_parameters (FILE *fp,
      * Parameters for vorstra
      */
     if (post_par->operator_vorstra__set)
-	fprintf(fp, "%s.%s: %d\n",
+	fprintf(fp, "%s.%s %d\n",
                 GPIV_POSTPAR_KEY,
                 POSTPAR_KEY__OPERATOR_VORSTRA, 
 		post_par->operator_vorstra);
     
     if (post_par->diff_type__set)
-	fprintf(fp, "%s.%s: %d\n",
+	fprintf(fp, "%s.%s %d\n",
                 GPIV_POSTPAR_KEY,
                 POSTPAR_KEY__DIFF_TYPE,
 		post_par->diff_type);
@@ -595,7 +596,7 @@ gpiv_post_print_parameters (FILE *fp,
      * Parameter for scale
      */
     if (post_par->scale_type__set)
-	fprintf(fp, "%s.%s: %d\n",
+	fprintf(fp, "%s.%s %d\n",
                 GPIV_POSTPAR_KEY,
                 POSTPAR_KEY__SCALE_TYPE, 
                 post_par->scale_type);
