@@ -4,7 +4,7 @@
 /*
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2004, 2005 
+   Copyright (C) 2004, 2005, 2006, 2007, 2008
    Gerber van der Graaf <gerber_graaf@users.sourceforge.net>
    Julio Soria <julio.soria@eng.monash.edu.au>
 
@@ -38,7 +38,7 @@ EXTERNAL FUNCTIONS:
                          gpiv_trig_fprint_parameters
                          gpiv_trig_fread_hdf5_parameters
 
-LAST MODIFICATION DATE:  $Id: trig_par.c,v 1.6 2008-04-09 06:10:28 gerber Exp $
+LAST MODIFICATION DATE:  $Id: trig_par.c,v 1.7 2008-05-05 14:38:42 gerber Exp $
 --------------------------------------------------------------------------- */
 
 
@@ -189,7 +189,7 @@ gpiv_trig_check_parameters_read (GpivTrigPar *trig_par,
             err_msg = "Using default: ";
             trig_par->ttime.cam_acq_period = trig_par_default->ttime.cam_acq_period;
         }
-        gpiv_warning("%s\n%s.%s: %lld", err_msg, 
+        gpiv_warning("%s\n%s.%s %lld", err_msg, 
                      GPIV_TRIGPAR_KEY,
                      GPIV_TRIGPAR_KEY__CAP,
                      trig_par_default->ttime.cam_acq_period /* * GPIV_NANO2MILI */);
@@ -204,7 +204,7 @@ gpiv_trig_check_parameters_read (GpivTrigPar *trig_par,
             err_msg = "Using default from libgpiv: ";
             trig_par->ttime.laser_trig_pw = trig_par_default->ttime.laser_trig_pw;
         }
-        gpiv_warning("%s\n%.%s: %lld", err_msg, 
+        gpiv_warning("%s\n%.%s %lld", err_msg, 
                      GPIV_TRIGPAR_KEY,
                      GPIV_TRIGPAR_KEY__LPW,
                      trig_par_default->ttime.laser_trig_pw/*  * GPIV_NANO2MILI */);
@@ -219,7 +219,7 @@ gpiv_trig_check_parameters_read (GpivTrigPar *trig_par,
             err_msg = "Using default: ";
             trig_par->ttime.time2laser = trig_par_default->ttime.time2laser;
         }
-        gpiv_warning("%s\n%s.%s: %lld", err_msg, 
+        gpiv_warning("%s\n%s.%s %lld", err_msg, 
                      GPIV_TRIGPAR_KEY,
                      GPIV_TRIGPAR_KEY__T2L,
                      trig_par_default->ttime.time2laser/*  * GPIV_NANO2MILI */);
@@ -234,7 +234,7 @@ gpiv_trig_check_parameters_read (GpivTrigPar *trig_par,
             err_msg = "Using default: ";
             trig_par->ttime.dt = GPIV_TRIGPAR_DEFAULT__DT;
         }
-        gpiv_warning("%s\n%s.%s: %lld", err_msg, 
+        gpiv_warning("%s\n%s.%s %lld", err_msg, 
                      GPIV_TRIGPAR_KEY,
                      GPIV_TRIGPAR_KEY__DT,
                      trig_par_default->ttime.dt/*  * GPIV_NANO2MILI */);
@@ -249,7 +249,7 @@ gpiv_trig_check_parameters_read (GpivTrigPar *trig_par,
             err_msg = "Using default: ";
             trig_par->ttime.mode = trig_par_default->ttime.mode;
         }
-        gpiv_warning("%s\n%s.%s: %d", err_msg,
+        gpiv_warning("%s\n%s.%s %d", err_msg,
                      GPIV_TRIGPAR_KEY,
                      GPIV_TRIGPAR_KEY__MODE,
                      trig_par_default->ttime.mode);
@@ -264,7 +264,7 @@ gpiv_trig_check_parameters_read (GpivTrigPar *trig_par,
             err_msg = "Using default: ";
             trig_par->ttime.cycles = trig_par_default->ttime.cycles;
         }
-        gpiv_warning("%s\n%.%s: %d", err_msg,
+        gpiv_warning("%s\n%.%s %d", err_msg,
                      GPIV_TRIGPAR_KEY,
                      GPIV_TRIGPAR_KEY__CYCLES,
                      trig_par_default->ttime.cycles);
@@ -279,7 +279,7 @@ gpiv_trig_check_parameters_read (GpivTrigPar *trig_par,
             err_msg = "Using default: ";
             trig_par->ttime.increment = trig_par_default->ttime.increment;
         }
-       gpiv_warning("%s\n%s.%s: %lld", err_msg, 
+       gpiv_warning("%s\n%s.%s %lld", err_msg, 
                      GPIV_TRIGPAR_KEY,
                      GPIV_TRIGPAR_KEY__INCR_DT,
                      trig_par_default->ttime.increment/*  * GPIV_NANO2MILI */);
@@ -412,7 +412,7 @@ gpiv_trig_print_parameters (FILE * fp_par_out,
 
     if (trig_par->ttime__cam_acq_period__set) {
         val = trig_par->ttime.cam_acq_period * GPIV_MILI2NANO;
-	fprintf(fp_par_out, "%s.%s: %f\n", 
+	fprintf(fp_par_out, "%s.%s %f\n", 
                 GPIV_TRIGPAR_KEY, 
                 GPIV_TRIGPAR_KEY__CAP, 
 		val);
@@ -420,7 +420,7 @@ gpiv_trig_print_parameters (FILE * fp_par_out,
 
     if (trig_par->ttime__laser_trig_pw__set) {
         val = trig_par->ttime.laser_trig_pw * GPIV_MILI2NANO;
-	fprintf(fp_par_out, "%s.%s: %f\n", 
+	fprintf(fp_par_out, "%s.%s %f\n", 
                 GPIV_TRIGPAR_KEY, 
                 GPIV_TRIGPAR_KEY__LPW, 
 		val);
@@ -428,7 +428,7 @@ gpiv_trig_print_parameters (FILE * fp_par_out,
 
     if (trig_par->ttime__time2laser__set) {
         val = trig_par->ttime.time2laser * GPIV_MILI2NANO;
-	fprintf(fp_par_out, "%s.%s: %f\n", 
+	fprintf(fp_par_out, "%s.%s %f\n", 
                 GPIV_TRIGPAR_KEY, 
                 GPIV_TRIGPAR_KEY__T2L, 
 		val);
@@ -436,21 +436,21 @@ gpiv_trig_print_parameters (FILE * fp_par_out,
 
     if (trig_par->ttime__dt__set) {
         val = trig_par->ttime.dt * GPIV_MILI2NANO;
-	fprintf(fp_par_out, "%s.%s: %f\n", 
+	fprintf(fp_par_out, "%s.%s %f\n", 
                 GPIV_TRIGPAR_KEY, 
                 GPIV_TRIGPAR_KEY__DT, 
 		val);
     }
 
     if (trig_par->ttime__mode__set) {
-	fprintf(fp_par_out, "%s.%s: %d\n", 
+	fprintf(fp_par_out, "%s.%s %d\n", 
                 GPIV_TRIGPAR_KEY, 
                 GPIV_TRIGPAR_KEY__MODE, 
 		trig_par->ttime.mode);
     }
 
     if (trig_par->ttime__cycles__set) {
-	fprintf(fp_par_out, "%s.%s: %d\n", 
+	fprintf(fp_par_out, "%s.%s %d\n", 
                 GPIV_TRIGPAR_KEY, 
                 GPIV_TRIGPAR_KEY__CYCLES, 
 		trig_par->ttime.cycles);
@@ -458,7 +458,7 @@ gpiv_trig_print_parameters (FILE * fp_par_out,
 
     if (trig_par->ttime__increment__set) {
         val = trig_par->ttime.increment * GPIV_MILI2NANO;
-	fprintf(fp_par_out, "%s.%s: %f\n", 
+	fprintf(fp_par_out, "%s.%s %f\n", 
                 GPIV_TRIGPAR_KEY, 
                 GPIV_TRIGPAR_KEY__INCR_DT, 
 		val);
