@@ -3,7 +3,8 @@
 /*
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of libgpiv.
    Libgpiv is free software; you can redistribute it and/or modify
@@ -43,7 +44,7 @@ EXTERNAL FUNCTIONS:
 LOCAL FUNCTIONS:         compare_float
                          local_scan_parameter
 
-LAST MODIFICATION DATE:  $Id: utils.c,v 1.24 2008-04-09 06:10:28 gerber Exp $
+LAST MODIFICATION DATE:  $Id: utils.c,v 1.27 2008-09-25 13:19:53 gerber Exp $
  --------------------------------------------------------------------------- */
 
 #include <string.h>
@@ -109,10 +110,15 @@ gpiv_scan_parameter (const gchar *PAR_KEY,
 {
     gchar *err_msg = NULL;
     FILE *fp_par;
+    gchar system_rsc[GPIV_MAX_CHARS];
+
+    snprintf(system_rsc, GPIV_MAX_CHARS, "%s/%s", SYSTEM_RSC_DIR, 
+             GPIV_SYSTEM_RSC_FILE);
 
     if ((fp_par = fopen (PARFILE, "rb")) == NULL) {
         if (verbose) {
             gpiv_warning ("gpiv_scan_parameter: failing fopen(%s)", PARFILE);
+            gpiv_warning ("You may copy this file from %s", system_rsc);
         }
         return;
     }
@@ -159,33 +165,40 @@ gpiv_scan_resourcefiles (const gchar *PAR_KEY,
     const gchar *home_dir = NULL;
     gchar home_rsc[GPIV_MAX_CHARS]; 
     gchar system_rsc[GPIV_MAX_CHARS];
-   
+    gboolean home_rsc__exist = TRUE;   
+
+    snprintf(system_rsc, GPIV_MAX_CHARS, "%s/%s", SYSTEM_RSC_DIR, 
+             GPIV_SYSTEM_RSC_FILE);
+
+    home_dir = g_get_home_dir ();
+    snprintf(home_rsc, GPIV_MAX_CHARS, "%s/%s", home_dir, GPIV_HOME_RSC_FILE);
 
 /*
  * Reads from home_rsc
  */
-    home_dir = g_get_home_dir ();
-    snprintf(home_rsc, GPIV_MAX_CHARS, "%s/%s", home_dir, GPIV_HOME_RSC_FILE);
-
     if ((fp_par=fopen (home_rsc, "rb")) == NULL) {
-        if (verbose) g_message ("gpiv_scan_resourcefiles: failing fopen(%s)", home_rsc);
-        return ("gpiv_scan_resourcefiles: failing fopen");
+        if (verbose) {
+            g_message ("gpiv_scan_resourcefiles: failing fopen(%s)", home_rsc);
+            g_message ("You may copy this file from %s\n", system_rsc);
+        }
+        home_rsc__exist = FALSE;
+    } else {
+        home_rsc__exist = TRUE;
     }
 
-    if ((err_msg = 
-         local_scan_parameter (fp_par, home_rsc, PAR_KEY, pstruct, verbose))
-        != NULL) {
-         ("gpiv_scan_resourcefiles: %s", err_msg);
-        return err_msg;
+    if (home_rsc__exist) {
+        if ((err_msg = 
+             local_scan_parameter (fp_par, home_rsc, PAR_KEY, pstruct, verbose))
+            != NULL) {
+            ("gpiv_scan_resourcefiles: %s", err_msg);
+            return err_msg;
+        }
+        fclose(fp_par);
     }
-    fclose(fp_par);
 
 /*
  * Reads from system_rsc
  */
-    snprintf(system_rsc, GPIV_MAX_CHARS, "%s/%s", SYSTEM_RSC_DIR, 
-             GPIV_SYSTEM_RSC_FILE);
-
     if ((fp_par = fopen (system_rsc, "rb")) == NULL) {
         if (verbose) g_message ("gpiv_scan_resourcefiles: failing fopen(%s)", system_rsc);
         return ("gpiv_scan_resourcefiles: failing fopen");
@@ -539,8 +552,12 @@ gpiv_error (gchar *message, ...
     vfprintf (stderr, message, args);
     fprintf (stderr,"\n");
     va_end (args);
-    
 
+
+#ifdef ENABLE_MPI
+    MPI_Finalize();
+/*     MPI_Abort(MPI_COMM_WORLD, rc); */
+#endif
     exit (1);
 }
 
@@ -638,9 +655,9 @@ gpiv_fscan_iph_nl (FILE *fp_h,
 
 
     if (use_mod_key) {
-        tmp_string = g_strdup_printf("%s.%s:", MOD_KEY, PAR_KEY);
+        tmp_string = g_strdup_printf("%s.%s", MOD_KEY, PAR_KEY);
     } else {
-        tmp_string = g_strdup_printf("%s:", PAR_KEY);
+        tmp_string = g_strdup_printf("%s", PAR_KEY);
     }
     
     if (strcmp (par_name, tmp_string) == 0) {
@@ -682,9 +699,9 @@ gpiv_scan_iph (const gchar *MOD_KEY,
 
     if (fp == NULL) fp = stdout;
     if (use_mod_key) {
-        tmp_string = g_strdup_printf("%s.%s:", MOD_KEY, PAR_KEY);
+        tmp_string = g_strdup_printf("%s.%s", MOD_KEY, PAR_KEY);
     } else {
-        tmp_string = g_strdup_printf("%s:", PAR_KEY);
+        tmp_string = g_strdup_printf("%s", PAR_KEY);
     }
     
     if (strcmp (par_name, tmp_string) == 0) {
@@ -722,9 +739,9 @@ gpiv_scan_cph (const gchar *MOD_KEY,
 
     if (fp == NULL) fp = stdout;
     if (use_mod_key) {
-        tmp_string = g_strdup_printf("%s.%s:", MOD_KEY, PAR_KEY);
+        tmp_string = g_strdup_printf("%s.%s", MOD_KEY, PAR_KEY);
     } else {
-        tmp_string = g_strdup_printf("%s:", PAR_KEY);
+        tmp_string = g_strdup_printf("%s", PAR_KEY);
     }
     
     if (strcmp (par_name, tmp_string) == 0) {
@@ -763,9 +780,9 @@ gpiv_scan_fph (const gchar *MOD_KEY,
 
     if (fp == NULL) fp = stdout;
     if (use_mod_key) {
-        tmp_string = g_strdup_printf("%s.%s:", MOD_KEY, PAR_KEY);
+        tmp_string = g_strdup_printf("%s.%s", MOD_KEY, PAR_KEY);
     } else {
-        tmp_string = g_strdup_printf("%s:", PAR_KEY);
+        tmp_string = g_strdup_printf("%s", PAR_KEY);
     }
     
     if (strcmp (par_name, tmp_string) == 0) {
@@ -805,9 +822,9 @@ gpiv_scan_sph (const gchar *MOD_KEY,
 
     if (fp == NULL) fp = stdout;
     if (use_mod_key) {
-        tmp_string = g_strdup_printf("%s.%s:", MOD_KEY, PAR_KEY);
+        tmp_string = g_strdup_printf("%s.%s", MOD_KEY, PAR_KEY);
     } else {
-        tmp_string = g_strdup_printf("%s:", PAR_KEY);
+        tmp_string = g_strdup_printf("%s", PAR_KEY);
     }
     
     key_length = strlen (tmp_string) + 1;
