@@ -3,7 +3,8 @@
 /*
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of libgpiv.
    Libgpiv is free software; you can redistribute it and/or modify
@@ -33,7 +34,7 @@ EXTERNAL FUNCTIONS:      gpiv_valid_residu
                          gpiv_valid_threshold
                          gpiv_cumhisto_eqdatbin_gnuplot
 
-LAST MODIFICATION DATE: $Id: valid.c,v 1.24 2008-04-09 06:10:28 gerber Exp $
+LAST MODIFICATION DATE: $Id: valid.c,v 1.25 2008-09-25 13:19:53 gerber Exp $
 --------------------------------------------------------------------- */
 #include <gpiv.h>
 
@@ -280,36 +281,40 @@ gpiv_valid_residu (GpivPivData *piv_data,
  *---------------------------------------------------------------------------*/
 {
     gchar *err_msg = NULL;
-/*     GpivPivData *out_data = NULL; */
-    gint i, j, i_mx, j_mx, i_my, j_my;
+    gint i, j;
+/*     guint i_mx, j_mx, i_my, j_my; */
 
 
 /*     out_data = gpiv_cp_pivdata (piv_data); */
 
     if (valid_par->residu_type == GPIV_VALID_RESIDUTYPE__SNR) {
 /* Nothing to do here */
-/*         for (i = 1; i < piv_data->ny - 1; i++) { */
-/*             for (j = 1; j < piv_data->nx - 1; j++) { */
-/*                 out_data->snr[i][j] = piv_data->snr[i][j]; */
-/*             } */
-/*         } */
 
     } else if (valid_par->residu_type == GPIV_VALID_RESIDUTYPE__MEDIAN) {
+
+/* #pragma omp parallel for */
         for (i = 1; i < piv_data->ny - 1; i++) {
             for (j = 1; j < piv_data->nx - 1; j++) {
-                /* out */piv_data->snr[i][j] = 
+                guint i_mx, j_mx, i_my, j_my;
+
+                piv_data->snr[i][j] = 
                     median_residu (i, j, valid_par->neighbors, 
                                    incl_point, FALSE, piv_data, 
                                    &i_mx, &j_mx, &i_my, &j_my);
-                if (/* out */piv_data->snr[i][j] == SNR_ERR) 
-                    /* out */piv_data->peak_no[i][j] = -1;
+                if (piv_data->snr[i][j] == SNR_ERR) 
+                    piv_data->peak_no[i][j] = -1;
             }
         }
 
     } else if (valid_par->residu_type == GPIV_VALID_RESIDUTYPE__NORMMEDIAN) {
         gfloat residu_from_median_dxdy = 1.111, residu_norm = 5.555;
+
+/* BUGFIX: gpiv_valid_residu: different results with OMP */
+/* #pragma omp parallel for private(residu_from_median_dxdy, residu_norm) */
         for (i = 0; i < piv_data->ny; i++) {
             for (j = 0; j < piv_data->nx; j++) {
+                guint i_mx, j_mx, i_my, j_my;
+
                  residu_norm = 
                      median_residu (i, j, valid_par->neighbors, 
                                     FALSE, TRUE, piv_data, 
@@ -319,13 +324,14 @@ gpiv_valid_residu (GpivPivData *piv_data,
                                     FALSE, FALSE, piv_data, 
                                     &i_mx, &j_mx, &i_my, &j_my);
                  if (residu_norm + RESIDU_EPSI != 0.0) {
-                     /* out */piv_data->snr[i][j] = 
+                     piv_data->snr[i][j] = 
                          residu_from_median_dxdy / 
                          (residu_norm + RESIDU_EPSI);
                  } else {
-                     /* out */piv_data->snr[i][j] = SNR_ERR;
-                     /* out */piv_data->peak_no[i][j] = -1;
+                     piv_data->snr[i][j] = SNR_ERR;
+                     piv_data->peak_no[i][j] = -1;
                  }
+
             }
         }
 
@@ -334,7 +340,6 @@ gpiv_valid_residu (GpivPivData *piv_data,
     }
 
 
-/*     return out_data; */
     return err_msg;
 }
 
@@ -459,13 +464,13 @@ subst_vector (GpivPivData *piv_data,
  *---------------------------------------------------------------------------*/
 {
     gboolean outlier_found = FALSE;
-    guint i, j, i_mx, j_mx, i_my, j_my, k, l;
+    gint i, j;
+    guint k, l;
     const gint N = valid_par->neighbors - 2;
     char line[GPIV_MAX_CHARS], command[GPIV_MAX_CHARS];
-    guint count;
     guint peak_no;
     gfloat row = 0, col = 0;
-    gfloat dx, dy, snr, dx_sum, dy_sum;
+    gfloat dx, dy, snr;
     FILE *fp;
 
 /* 
@@ -478,18 +483,21 @@ subst_vector (GpivPivData *piv_data,
 
     l_data = gpiv_cp_pivdata (piv_data);
 
-    for (i = 0; i < piv_data->ny; i++) {
-        for (j = 0; j < piv_data->nx; j++) {
-
-            if (piv_data->peak_no[i][j] != -1 
-                && piv_data->snr[i][j] > valid_par->residu_max) {
-                outlier_found = TRUE;
-/*                  } */
+    if (valid_par->subst_type == 
+        GPIV_VALID_SUBSTYPE__NONE) {
 /*
  * no substitution, only sets peak_no to 0
  */
-                if (valid_par->subst_type == 
-                    GPIV_VALID_SUBSTYPE__NONE) {
+
+#pragma omp parallel for
+        for (i = 0; i < piv_data->ny; i++) {
+            for (j = 0; j < piv_data->nx; j++) {
+                guint i_mx, j_mx, i_my, j_my;
+
+                if (piv_data->peak_no[i][j] != -1 
+                    && piv_data->snr[i][j] > valid_par->residu_max) {
+                    outlier_found = TRUE;
+
                     l_data->dx[i][j] = piv_data->dx[i][j];
                     l_data->dy[i][j] = piv_data->dy[i][j];
                     l_data->snr[i][j] = piv_data->snr[i][j];
@@ -498,12 +506,25 @@ subst_vector (GpivPivData *piv_data,
                     } else {
                         l_data->peak_no[i][j] = 0;
                     }
+                }
+            }
+        }
+
+
+    } else if (valid_par->subst_type == 
+               GPIV_VALID_SUBSTYPE__L_MEAN) {
+
+#pragma omp parallel for
+        for (i = 0; i < piv_data->ny; i++) {
+            for (j = 0; j < piv_data->nx; j++) {
+                guint i_mx, j_mx, i_my, j_my;
+                guint count = 0;
+                gfloat dx_sum = 0, dy_sum = 0;
+
+                if (piv_data->peak_no[i][j] != -1 
+                    && piv_data->snr[i][j] > valid_par->residu_max) {
+                    outlier_found = TRUE;
 
-                } else if (valid_par->subst_type == 
-                           GPIV_VALID_SUBSTYPE__L_MEAN) {
-                    count = 0;
-                    dx_sum = 0;
-                    dy_sum = 0;
                     for (k = i - N; k <= i + N; k++) {
                         if ((k >= 0) && (k < piv_data->ny)) {
                             for (l = j - N; l <= j + N; l++) {
@@ -524,14 +545,26 @@ subst_vector (GpivPivData *piv_data,
                     l_data->dy[i][j] = dy_sum / count;
                     l_data->snr[i][j] = piv_data->snr[i][j];
                     l_data->peak_no[i][j] = 0;
+                }
+            }
+        }
 
 
-
+    } else if (valid_par->subst_type == 
+               GPIV_VALID_SUBSTYPE__MEDIAN) {
 /*
  * Substitution with  median particle displacements
  */
-                } else if (valid_par->subst_type == 
-                           GPIV_VALID_SUBSTYPE__MEDIAN) {
+        
+#pragma omp parallel for
+        for (i = 0; i < piv_data->ny; i++) {
+            for (j = 0; j < piv_data->nx; j++) {
+                guint i_mx, j_mx, i_my, j_my;
+                
+                if (piv_data->peak_no[i][j] != -1 
+                    && piv_data->snr[i][j] > valid_par->residu_max) {
+                    outlier_found = TRUE;
+      
                     l_data->snr[i][j] = 
                         median_residu (i, j, valid_par->neighbors, 
                                        FALSE, FALSE, piv_data, 
@@ -544,19 +577,34 @@ subst_vector (GpivPivData *piv_data,
                         l_data->peak_no[i][j] = 0;
                     }
 
+                }
+            }
+        }
+            
+
+    } else if (valid_par->subst_type == 
+               GPIV_VALID_SUBSTYPE__COR_PEAK) {
 /*
  * substitution with image analyse of next higher correlation
  * peak (or higher)
  */
-                } else if (valid_par->subst_type == 
-                           GPIV_VALID_SUBSTYPE__COR_PEAK) {
+
+        for (i = 0; i < piv_data->ny; i++) {
+            for (j = 0; j < piv_data->nx; j++) {
+                if (piv_data->peak_no[i][j] != -1 
+                    && piv_data->snr[i][j] > valid_par->residu_max) {
+                    outlier_found = TRUE;
+
                     interr_reg_nhpeak (i, j, image, piv_par, l_data);
                 }
-
             }
-
         }
+
     }
+    
+
+
+
 
 /*
  * Copy back to original values and de-allocate local PIV data set
@@ -705,6 +753,7 @@ gpiv_valid_peaklck (const GpivPivData *piv_data,
 /*
  * Subdividing fractional particle displacements in bins
  */
+/* #pragma omp parallel for private(fract) */
     for (i = 0; i < piv_data->ny; i++) {
 	for (j = 0; j < piv_data->nx; j++) {
 	    fract = fabs(piv_data->dx[i][j] - (int) piv_data->dx[i][j]);
@@ -864,7 +913,6 @@ gpiv_valid_errvec (GpivPivData *piv_data,
  */
         l_data = gpiv_cp_pivdata (piv_data);
         gpiv_valid_residu (l_data, l_valid_par, TRUE);
-
         if (l_valid_par->subst_type != GPIV_VALID_SUBSTYPE__NONE
             && interrogate_valid) {
 /*
@@ -888,11 +936,12 @@ gpiv_valid_errvec (GpivPivData *piv_data,
             
 /*
  * piv_data are updated with corrected values 
- * l_data will be freed for eventually next loop
+ * l_data will be freed for an eventually next loop
  */
         if (outlier_found) {
             count++;
 
+#pragma omp parallel for
             for (i = 0; i < piv_data->ny; i++) {
                 for (j = 0; j < piv_data->nx; j++) {
                     piv_data->point_x[i][j] = l_data->point_x[i][j];
