@@ -3,7 +3,8 @@
 /*
    libgpiv - library for Particle Image Velocimetry
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of libgpiv.
    Libgpiv is free software; you can redistribute it and/or modify
@@ -38,7 +39,7 @@ EXTERNAL FUNCTIONS:
                          gpiv_valid_fread_hdf5_parameters
                          gpiv_valid_fwrite_hdf5_parameters
 
-LAST MODIFICATION DATE: $Id: valid_par.c,v 1.7 2008-04-09 06:10:28 gerber Exp $
+LAST MODIFICATION DATE: $Id: valid_par.c,v 1.9 2008-09-25 13:19:54 gerber Exp $
 --------------------------------------------------------------------- */
 #include <gpiv.h>
 
@@ -225,7 +226,7 @@ gpiv_valid_check_parameters_read (GpivValidPar *valid_par,
             err_msg = "Using default: ";
             valid_par->data_yield = valid_par_default->data_yield;
         }
-        gpiv_warning("%s\n%s.%s: %f", 
+        gpiv_warning("%s\n%s.%s %f", 
                      err_msg, 
                      GPIV_VALIDPAR_KEY,
                      VALIDPAR_KEY__DATA_YIELD,
@@ -244,7 +245,7 @@ gpiv_valid_check_parameters_read (GpivValidPar *valid_par,
             err_msg = "Using default: ";
             valid_par->residu_max = valid_par_default->residu_max;
         }
-        gpiv_warning("%s\n%s.%s: %f", 
+        gpiv_warning("%s\n%s.%s %f", 
                      err_msg, 
                      GPIV_VALIDPAR_KEY,
                      VALIDPAR_KEY__RESIDU_MAX,
@@ -260,7 +261,7 @@ gpiv_valid_check_parameters_read (GpivValidPar *valid_par,
             err_msg = "Using default: ";
             valid_par->neighbors = valid_par_default->neighbors;
         }
-       gpiv_warning("%s\n%s.%s: %d", 
+       gpiv_warning("%s\n%s.%s %d", 
                      err_msg, 
                      GPIV_VALIDPAR_KEY,
                      VALIDPAR_KEY__NEIGHBORS,
@@ -279,7 +280,7 @@ gpiv_valid_check_parameters_read (GpivValidPar *valid_par,
             err_msg = "Using default: ";
             valid_par->residu_type = valid_par_default->residu_type;
         }
-        gpiv_warning("%s\n%s.%s: %d", 
+        gpiv_warning("%s\n%s.%s %d", 
                      err_msg, 
                      GPIV_VALIDPAR_KEY,
                      VALIDPAR_KEY__RESIDU_TYPE,
@@ -295,7 +296,7 @@ gpiv_valid_check_parameters_read (GpivValidPar *valid_par,
             err_msg = "Using default: ";
             valid_par->subst_type = valid_par_default->subst_type;
         }
-        gpiv_warning("%s\n%s.%s: %d", 
+        gpiv_warning("%s\n%s.%s %d", 
                      err_msg, 
                      GPIV_VALIDPAR_KEY,
                      VALIDPAR_KEY__SUBST_TYPE,
@@ -311,7 +312,7 @@ gpiv_valid_check_parameters_read (GpivValidPar *valid_par,
             err_msg = "Using default: ";
             valid_par->histo_type = valid_par_default->histo_type;
         }
-        gpiv_warning("%s\n%s.%s: %d", 
+        gpiv_warning("%s\n%s.%s %d", 
                      err_msg,
                      GPIV_VALIDPAR_KEY,
                      VALIDPAR_KEY__HISTO_TYPE,
@@ -403,32 +404,32 @@ gpiv_valid_print_parameters (FILE * fp,
 
         /* Outliers */
         if (valid_par->subst_type__set)
-            printf ("%s.%s: %d\n", GPIV_VALIDPAR_KEY,  
+            printf ("%s.%s %d\n", GPIV_VALIDPAR_KEY,  
                     VALIDPAR_KEY__SUBST_TYPE, 
                     valid_par->subst_type);
 
         if (valid_par->histo_type__set)
-            printf ("%s.%s: %d\n", GPIV_VALIDPAR_KEY,  
+            printf ("%s.%s %d\n", GPIV_VALIDPAR_KEY,  
                     VALIDPAR_KEY__HISTO_TYPE, 
                     valid_par->histo_type);
 
         if (valid_par->residu_type__set)
-            printf ("%s.%s: %d\n", GPIV_VALIDPAR_KEY,  
+            printf ("%s.%s %d\n", GPIV_VALIDPAR_KEY,  
                     VALIDPAR_KEY__RESIDU_TYPE, 
                     valid_par->residu_type);
 
         if (valid_par->residu_max__set)
-            printf ("%s.%s: %f\n", GPIV_VALIDPAR_KEY,  
+            printf ("%s.%s %f\n", GPIV_VALIDPAR_KEY,  
                     VALIDPAR_KEY__RESIDU_MAX, 
                     valid_par->residu_max);
 
         if (valid_par->neighbors__set)
-            printf ("%s.%s: %d\n", GPIV_VALIDPAR_KEY,  
+            printf ("%s.%s %d\n", GPIV_VALIDPAR_KEY,  
                     VALIDPAR_KEY__NEIGHBORS, 
                     valid_par->neighbors);
 
         if (valid_par->data_yield__set)
-            printf ("%s.%s: %f\n", GPIV_VALIDPAR_KEY,  
+            printf ("%s.%s %f\n", GPIV_VALIDPAR_KEY,  
                     VALIDPAR_KEY__DATA_YIELD, 
                     valid_par->data_yield);
 
@@ -438,32 +439,32 @@ gpiv_valid_print_parameters (FILE * fp,
 
         /* Outliers */
         if (valid_par->subst_type__set)
-            fprintf (fp, "%s.%s: %d\n", GPIV_VALIDPAR_KEY,  
+            fprintf (fp, "%s.%s %d\n", GPIV_VALIDPAR_KEY,  
                     VALIDPAR_KEY__SUBST_TYPE, 
                     valid_par->subst_type);
 
         if (valid_par->histo_type__set)
-            fprintf (fp, "%s.%s: %d\n", GPIV_VALIDPAR_KEY,  
+            fprintf (fp, "%s.%s %d\n", GPIV_VALIDPAR_KEY,  
                     VALIDPAR_KEY__HISTO_TYPE, 
                     valid_par->histo_type);
 
         if (valid_par->residu_type__set)
-            fprintf (fp, "%s.%s: %d\n", GPIV_VALIDPAR_KEY,  
+            fprintf (fp, "%s.%s %d\n", GPIV_VALIDPAR_KEY,  
                     VALIDPAR_KEY__RESIDU_TYPE, 
                     valid_par->residu_type);
 
         if (valid_par->residu_max__set)
-            fprintf (fp, "%s.%s: %f\n", GPIV_VALIDPAR_KEY,  
+            fprintf (fp, "%s.%s %f\n", GPIV_VALIDPAR_KEY,  
                     VALIDPAR_KEY__RESIDU_MAX, 
                     valid_par->residu_max);
 
         if (valid_par->neighbors__set)
-            fprintf (fp, "%s.%s: %d\n", GPIV_VALIDPAR_KEY,  
+            fprintf (fp, "%s.%s %d\n", GPIV_VALIDPAR_KEY,  
                     VALIDPAR_KEY__NEIGHBORS, 
                     valid_par->neighbors);
 
         if (valid_par->data_yield__set)
-            fprintf (fp, "%s.%s: %f\n", GPIV_VALIDPAR_KEY,  
+            fprintf (fp, "%s.%s %f\n", GPIV_VALIDPAR_KEY,  
                     VALIDPAR_KEY__DATA_YIELD, 
                     valid_par->data_yield);
     }
@@ -894,4 +895,47 @@ obtain_valdipar_fromline (char line[],
 }
 
 
+#ifdef ENABLE_MPI
+void
+gpiv_valid_mpi_bcast_validpar (GpivValidPar *valid_par)
+/*-----------------------------------------------------------------------------
+ * Broadcasts valid_par
+ */
+{
+    if (
+        MPI_Bcast(&valid_par->data_yield, 1, MPI_FLOAT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&valid_par->data_yield__set, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
 
+        || MPI_Bcast(&valid_par->residu_max, 1, MPI_FLOAT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&valid_par->residu_max__set, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&valid_par->neighbors, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&valid_par->neighbors__set, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&valid_par->residu_type, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&valid_par->residu_type__set, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&valid_par->subst_type, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&valid_par->subst_type__set, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        || MPI_Bcast(&valid_par->histo_type, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+        || MPI_Bcast(&valid_par->histo_type__set, 1, MPI_INT, 0, MPI_COMM_WORLD) 
+        != MPI_SUCCESS
+
+        ) {
+        gpiv_error("ALL SHIPS AND PIRATES! mpi_bcast_validpar: An error ocurred in MPI_Bcast");
+    }
+}
+
+#endif /* ENABLE_MPI */
